@@ -20,6 +20,7 @@ from distutils.util import change_root
 from distutils.spawn import find_executable
 from distutils.core import Command
 
+
 class po_stats(Command):
     description = "Show translation statistics"
     user_options = []
@@ -42,6 +43,7 @@ class po_stats(Command):
             p = Popen(["msgfmt", "--statistics", po], stdout=PIPE, stderr=PIPE)
             output = p.communicate()[1]
             res.append((language, output))
+        del p
 
         stats = []
         for po, r in res:
@@ -52,29 +54,11 @@ class po_stats(Command):
             stats.append((po, trans, fuzzy, untrans))
 
         stats.sort(key=lambda x: x[1], reverse=True)
-        print "#"*30
+        print "#" * 30
         for po, trans, fuzzy, untrans in stats:
-            all_ = float(trans + fuzzy + untrans)/100
-            print "%5s: %3d%% (+%2d%% fuzzy)" % (po, trans/all_, fuzzy/all_)
-
-
-class check_pot(Command):
-    description = "check for missing files in POTFILES.in"
-    user_options = []
-
-    def initialize_options(self):
-        pass
-
-    def finalize_options(self):
-        self.po_directory = self.distribution.po_directory
-        self.po_package = self.distribution.po_package
-
-    def run(self):
-        oldpath = os.getcwd()
-        os.chdir(self.po_directory)
-        self.spawn(["intltool-update", "--maintain",
-                    "--gettext-package", self.po_package])
-        os.chdir(oldpath)
+            all_ = float(trans + fuzzy + untrans) / 100
+            print ("%5s: %3d%% (+%2d%% fuzzy)" %
+                   (po, trans / all_, fuzzy / all_))
 
 
 class build_mo(Command):
@@ -133,6 +117,7 @@ class build_mo(Command):
                 self.mkpath(fullpath)
                 self.spawn(["msgfmt", "-o", destpath, po])
 
+
 class install_mo(Command):
     """install message catalog files
 
@@ -149,7 +134,7 @@ class install_mo(Command):
     root = None
 
     def initialize_options(self):
-        pass
+        self.outfiles = []
 
     def finalize_options(self):
         self.set_undefined_options('build', ('build_base', 'build_base'))
@@ -159,13 +144,17 @@ class install_mo(Command):
             ('install_base', 'install_base'),
             ('skip_build', 'skip_build'))
 
+    def get_outputs(self):
+        return self.outfiles
+
     def run(self):
         if not self.skip_build:
             self.run_command('build_mo')
         src = os.path.join(self.build_base, "share", "locale")
         dest = os.path.join(self.install_base, "share", "locale")
-        if self.root != None:
+        if self.root is not None:
             dest = change_root(self.root, dest)
-        self.copy_tree(src, dest)
+        out = self.copy_tree(src, dest)
+        self.outfiles.extend(out)
 
-__all__ = ["build_mo", "install_mo", "po_stats", "check_pot"]
+__all__ = ["build_mo", "install_mo", "po_stats"]
