@@ -11,6 +11,7 @@ from distutils.dep_util import newer
 from distutils.util import change_root
 from distutils.core import Command
 
+
 class build_shortcuts(Command):
     """Build .desktop files
 
@@ -49,6 +50,7 @@ class build_shortcuts(Command):
             else:
                 self.copy_file(shortcut, os.path.join(basepath, shortcut))
 
+
 class install_shortcuts(Command):
     """Install .desktop files
 
@@ -66,7 +68,7 @@ class install_shortcuts(Command):
     root = None
 
     def initialize_options(self):
-        pass
+        self.outfiles = []
 
     def finalize_options(self):
         self.set_undefined_options('build', ('build_base', 'build_base'))
@@ -79,18 +81,23 @@ class install_shortcuts(Command):
         self.set_undefined_options(
             'build_shortcuts', ('shortcuts', 'shortcuts'))
 
+    def get_outputs(self):
+        return self.outfiles
+
     def run(self):
         if not self.skip_build:
             self.run_command('build_shortcuts')
         basepath = os.path.join(self.prefix, 'share', 'applications')
-        if self.root != None:
+        if self.root is not None:
             basepath = change_root(self.root, basepath)
         srcpath = os.path.join(self.build_base, 'share', 'applications')
-        self.mkpath(basepath)
+        out = self.mkpath(basepath)
+        self.outfiles.extend(out or [])
         for shortcut in self.shortcuts:
             shortcut = os.path.basename(shortcut)
             fullsrc = os.path.join(srcpath, shortcut)
             fullpath = os.path.join(basepath, shortcut)
-            self.copy_file(fullsrc, fullpath)
+            (out, _) = self.copy_file(fullsrc, fullpath)
+            self.outfiles.append(out)
 
 __all__ = ["build_shortcuts", "install_shortcuts"]
