@@ -419,10 +419,9 @@ class CloseButton(Gtk.Button):
         image = Gtk.Image(visible=True, can_focus=False,
                           icon_name="window-close-symbolic")
 
-        # Gtk.Align.CENTER (3) broken on Windows with gtk 3.8
         super(CloseButton, self).__init__(
             visible=False, can_focus=True, image=image,
-            relief=Gtk.ReliefStyle.NONE, valign=3)
+            relief=Gtk.ReliefStyle.NONE, valign=Gtk.Align.CENTER)
 
         ctx = self.get_style_context()
         ctx.add_class("raised")
@@ -455,11 +454,7 @@ class QuestionBar(Gtk.InfoBar):
 
         try:
             self.set_show_close_button(True)
-        except (AttributeError, GLib.GError):
-            # On Windows we use GTK+3.8 but the typelib is from 3.10.
-            # As a result libgirepository throws GError here because the
-            # library symbol is missing
-
+        except AttributeError:
             # < gtk3.10
             action = self.get_action_area()
             close_button = CloseButton()
@@ -566,8 +561,10 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
 
         # treeview
         scrolled_window = ScrolledWindow()
+        scrolled_window.show()
         scrolled_window.set_shadow_type(Gtk.ShadowType.IN)
         self.view = view = AllTreeView()
+        view.show()
         view.set_headers_visible(False)
         scrolled_window.set_policy(
             Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
@@ -624,11 +621,10 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
         box.pack_start(search, True, True, 0)
         box.pack_start(button, False, True, 0)
         if main:
-            self.pack_start(Alignment(box, left=6, right=6, top=6),
-                            True, True, 0)
+            self._searchbox = Alignment(box, left=0, right=6, top=6)
         else:
-            self.pack_start(box, True, True, 0)
-        self.__filter_list = scrolled_window
+            self._searchbox = box
+        self._searchbox.show_all()
 
         def qbar_response(infobar, response_id):
             if response_id == infobar.RESPONSE_LOAD:
@@ -639,33 +635,32 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
         if self._is_library_empty():
             self.qbar.show()
 
-        self.show_all()
+        pane = qltk.RHPaned()
+        pane.show()
+        pane.pack1(scrolled_window, resize=False, shrink=False)
+        songbox = Gtk.VBox(spacing=6)
+        songbox.pack_start(self._searchbox, False, True, 0)
+        self._songpane_container = Gtk.VBox()
+        self._songpane_container.show()
+        songbox.pack_start(self._songpane_container, True, True, 0)
+        songbox.pack_start(self.qbar, False, True, 0)
+        songbox.show()
+        pane.pack2(songbox, resize=True, shrink=False)
+        self.pack_start(pane, True, True, 0)
+        self.show()
 
     def _is_library_empty(self):
         return not len(self.__stations) and not len(self.__fav_stations)
 
     def pack(self, songpane):
-        container = Gtk.VBox(spacing=6)
-
-        pane = qltk.RHPaned()
-        pane.pack1(self.__filter_list, resize=False, shrink=False)
-        pane.show_all()
-
-        songbox = Gtk.VBox(spacing=6)
-        songbox.pack_start(songpane, True, True, 0)
-        songbox.pack_start(self.qbar, False, True, 0)
-        songbox.show()
-
-        pane.pack2(songbox, resize=True, shrink=False)
-        container.pack_start(self, False, True, 0)
-        container.pack_start(pane, True, True, 0)
+        container = Gtk.VBox()
+        container.add(self)
+        self._songpane_container.add(songpane)
         return container
 
     def unpack(self, container, songpane):
+        self._songpane_container.remove(songpane)
         container.remove(self)
-        pane = container.get_children()[0]
-        box = pane.get_children()[1]
-        box.remove(songpane)
 
     def __update(self, *args):
         self.qbar.hide()
