@@ -21,14 +21,16 @@ from quodlibet.qltk.songsmenu import SongsMenu
 from quodlibet.qltk.wlw import WaitLoadBar
 from quodlibet.qltk.browser import LibraryBrowser
 from quodlibet.qltk.delete import DeleteDialog
-from quodlibet.qltk.x import Alignment, ScrolledWindow
+from quodlibet.qltk.x import Alignment, ScrolledWindow, Button
 
 
 class DeviceProperties(Gtk.Dialog):
     def __init__(self, parent, device):
         super(DeviceProperties, self).__init__(
-            _("Device Properties"), qltk.get_top_parent(parent),
-            buttons=(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE))
+            title=_("Device Properties"),
+            transient_for=qltk.get_top_parent(parent))
+
+        self.add_button(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
         self.set_default_size(400, -1)
         self.connect('response', self.__close)
 
@@ -80,7 +82,7 @@ class DeviceProperties(Gtk.Dialog):
                         widget.set_alignment(0.0, 0.5)
                     table.attach(widget, 1, 2, y, y + 1)
             y += 1
-        self.show_all()
+        self.get_child().show_all()
 
     def __changed(self, widget, key, device):
         if isinstance(widget, Gtk.Entry):
@@ -116,7 +118,7 @@ class Menu(Gtk.Menu):
         if len(MediaDevices.instances()) > 0:
             browser = MediaDevices.instances()[0]
         else:
-            win = LibraryBrowser(MediaDevices, library)
+            win = LibraryBrowser.open(MediaDevices, library)
             browser = win.browser
         browser.select(device)
         browser.dropped(browser.get_toplevel().songlist, songs)
@@ -207,15 +209,16 @@ class MediaDevices(Gtk.VBox, Browser, util.InstanceTracker):
         else:
             self.pack_start(hbox, False, True, 0)
 
-        self.__refresh_button = refresh = Gtk.Button(stock=Gtk.STOCK_REFRESH)
+        # refresh button
+        refresh = Button(_("_Refresh"), Gtk.STOCK_REFRESH, Gtk.IconSize.MENU)
+        self.__refresh_button = refresh
         refresh.connect_object('clicked', self.__refresh, True)
         refresh.set_sensitive(False)
         hbox.pack_start(refresh, True, True, 0)
 
-        self.__eject_button = eject = Gtk.Button(_("_Eject"),
-                                                 use_underline=True)
-        eject.set_image(
-            Gtk.Image.new_from_icon_name("media-eject", Gtk.IconSize.BUTTON))
+        # eject button
+        eject = Button(_("_Eject"), "media-eject", Gtk.IconSize.MENU)
+        self.__eject_button = eject
         eject.connect('clicked', self.__eject)
         eject.set_sensitive(False)
         hbox.pack_start(eject, True, True, 0)
@@ -248,7 +251,8 @@ class MediaDevices(Gtk.VBox, Browser, util.InstanceTracker):
 
         self.__statusbar = WaitLoadBar()
 
-        self.show_all()
+        for child in self.get_children():
+            child.show_all()
 
     def pack(self, songpane):
         self.__vbox = vbox = Gtk.VBox(spacing=6)
@@ -261,6 +265,7 @@ class MediaDevices(Gtk.VBox, Browser, util.InstanceTracker):
         self.__header.hide()
         self.__statusbar.show_all()
         self.__statusbar.hide()
+        self.show()
 
         self.__paned = paned = qltk.RHPaned()
         paned.pack1(self, True, False)
@@ -280,7 +285,7 @@ class MediaDevices(Gtk.VBox, Browser, util.InstanceTracker):
             delete = False
 
         menu = SongsMenu(library, songs, delete=delete, remove=False,
-                         accels=songlist.accelerators, parent=self)
+                         parent=self)
         return menu
 
     def activate(self):
@@ -531,8 +536,8 @@ class MediaDevices(Gtk.VBox, Browser, util.InstanceTracker):
         if not self.__check_device(device, _("Unable to delete songs")):
             return False
 
-        song_titles = [s('~artist~title') for s in songs]
-        if DeleteDialog(self, song_titles, False, True).run() != 2:
+        dialog = DeleteDialog.for_songs(self, songs)
+        if dialog.run() != DeleteDialog.RESPONSE_DELETE:
             return False
 
         self.__busy = True
