@@ -62,7 +62,7 @@ class SearchBar(Gtk.VBox, Browser):
         container.remove(self)
 
     def __init__(self, library, main):
-        super(SearchBar, self).__init__(library, main)
+        super(SearchBar, self).__init__()
         self.set_spacing(6)
 
         self._filter = None
@@ -127,7 +127,7 @@ class SearchBar(Gtk.VBox, Browser):
             GLib.idle_add(self.emit, 'songs-selected', songs, None)
 
     def __text_parse(self, bar, text):
-        self.filter_text(text)
+        self.activate()
 
     def save(self):
         config.set("browsers", "query_text", self._get_text())
@@ -138,7 +138,7 @@ class SearchBar(Gtk.VBox, Browser):
         except config.Error:
             return
 
-        self.filter_text(text)
+        self._set_text(text)
 
     def finalize(self, restore):
         config.set("browsers", "query_text", "")
