@@ -1,4 +1,4 @@
-# Copyright 2004-2012 Joe Wreschnig, Michael Urman, Niklas Janlert,
+# Copyright 2004-2013 Joe Wreschnig, Michael Urman, Niklas Janlert,
 #                     Steven Robertson, Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
@@ -7,9 +7,13 @@
 
 import mutagen.id3
 
-from quodlibet import config, const, print_d, util
+from quodlibet import config, const, print_d
+from quodlibet import util
+from quodlibet.config import RATINGS
 from quodlibet.formats._audio import AudioFile
+from quodlibet.formats._image import EmbeddedImage, APICType
 from quodlibet.util.massagers import LanguageMassager
+from quodlibet.util.path import get_temp_cover_file
 
 
 def isascii(s):
@@ -104,13 +108,6 @@ class ID3File(AudioFile):
         }
     PAM_XXXT = dict([(v, k) for k, v in TXXX_MAP.iteritems()])
 
-    CODECS = ["utf-8"]
-    try:
-        CODECS.extend(config.get("editing", "id3encoding").strip().split())
-    except:
-        pass  # Uninitialized config...
-    CODECS.append("iso-8859-1")
-
     Kind = None
 
     def __init__(self, filename):
@@ -119,7 +116,7 @@ class ID3File(AudioFile):
 
         for frame in tag.values():
             if frame.FrameID == "APIC" and len(frame.data):
-                self["~picture"] = "y"
+                self.has_images = True
                 continue
             elif frame.FrameID == "TCON":
                 self["genre"] = "\n".join(frame.genres)
@@ -251,6 +248,14 @@ class ID3File(AudioFile):
             self["replaygain_%s_gain" % k] = "%+f dB" % frame.gain
             self["replaygain_%s_peak" % k] = str(frame.peak)
 
+    @util.cached_property
+    def CODECS(self):
+        codecs = ["utf-8"]
+        codecs_conf = config.get("editing", "id3encoding")
+        codecs.extend(codecs_conf.strip().split())
+        codecs.append("iso-8859-1")
+        return codecs
+
     def __distrust_latin1(self, text, encoding):
         assert isinstance(text, unicode)
         if encoding == 0:
@@ -369,7 +374,9 @@ class ID3File(AudioFile):
                 pass
             # Add new ones
             if k in self:
-                tag.add(mutagen.id3.TXXX(encoding=0, text=self[k].split("\n"),
+                value = self[k]
+                tag.add(mutagen.id3.TXXX(encoding=encoding_for(value),
+                                         text=value.split("\n"),
                                          desc=k))
 
         # we shouldn't delete all, but we use unknown ones as fallback, so make
@@ -401,12 +408,14 @@ class ID3File(AudioFile):
                 pass
         for key in self.PAM_XXXT:
             if key in self:
-                f = mutagen.id3.TXXX(encoding=0, text=self[key].split("\n"),
+                value = self[key]
+                f = mutagen.id3.TXXX(encoding=encoding_for(value),
+                                     text=value.split("\n"),
                                      desc=self.PAM_XXXT[key])
                 tag.add(f)
 
         if (config.getboolean("editing", "save_to_songs") and
-                (self("~#rating") != const.DEFAULT_RATING or
+                (self("~#rating") != RATINGS.default or
                  self.get("~#playcount", 0) != 0)):
             email = config.get("editing", "save_email").strip()
             email = email or const.EMAIL
@@ -418,18 +427,76 @@ class ID3File(AudioFile):
         tag.save(self["~filename"])
         self.sanitize()
 
-    def get_format_cover(self):
+    can_change_images = True
+
+    def clear_images(self):
+        """Delete all embedded images"""
+
         try:
             tag = mutagen.id3.ID3(self["~filename"])
         except Exception:
             return
-        else:
-            cover = None
-            for frame in tag.getall("APIC"):
-                cover = cover or frame
-                if frame.type == 3:
-                    cover = frame
-                    break
 
-            if cover:
-                return util.get_temp_cover_file(cover.data)
+        tag.delall("APIC")
+        tag.save()
+
+        self.has_images = False
+
+    def get_images(self):
+        """Returns a list of embedded images"""
+
+        images = []
+
+        try:
+            tag = mutagen.id3.ID3(self["~filename"])
+        except Exception:
+            return images
+
+        for frame in tag.getall("APIC"):
+            f = get_temp_cover_file(frame.data)
+            images.append(EmbeddedImage(f, frame.mime, type_=frame.type))
+
+        images.sort(key=lambda c: c.sort_key)
+        return images
+
+    def get_primary_image(self):
+        """Returns the primary embedded image"""
+
+        try:
+            tag = mutagen.id3.ID3(self["~filename"])
+        except Exception:
+            return
+
+        # get the APIC frame with type == 3 (cover) or the first one
+        cover = None
+        for frame in tag.getall("APIC"):
+            cover = cover or frame
+            if frame.type == APICType.COVER_FRONT:
+                cover = frame
+                break
+
+        if cover:
+            f = get_temp_cover_file(cover.data)
+            return EmbeddedImage(f, cover.mime, type_=cover.type)
+
+    def set_image(self, image):
+        """Replaces all embedded images by the passed image"""
+
+        try:
+            tag = mutagen.id3.ID3(self["~filename"])
+        except Exception:
+            return
+
+        try:
+            data = image.file.read()
+        except EnvironmentError:
+            return
+
+        tag.delall("APIC")
+        frame = mutagen.id3.APIC(
+            encoding=3, mime=image.mime_type, type=APICType.COVER_FRONT,
+            desc=u"", data=data)
+        tag.add(frame)
+        tag.save()
+
+        self.has_images = True
