@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright 2005 Michael Urman, Joe Wreschnig
+#           2014 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -8,6 +9,7 @@
 from gi.repository import GObject
 
 from quodlibet import util
+from quodlibet.plugins import PluginHandler
 
 from quodlibet.util.songwrapper import SongWrapper, ListWrapper
 from quodlibet.util.songwrapper import check_wrapper_changed
@@ -28,6 +30,7 @@ class EventPlugin(object):
         obj.plugin_on_paused()
         obj.plugin_on_unpaused()
         obj.plugin_on_seek(song, msec)
+        obj.plugin_on_error(song, error)
     """
 
     PLUGIN_INSTANCE = True
@@ -66,7 +69,7 @@ def _map_signals(obj, prefix="plugin_on_", blacklist=None):
     return sigs
 
 
-class EventPluginHandler(object):
+class EventPluginHandler(PluginHandler):
 
     def __init__(self, librarian=None, player=None):
         if librarian:
@@ -77,7 +80,7 @@ class EventPluginHandler(object):
                 librarian.connect(event, handler, event)
 
         if librarian and player:
-            sigs = _map_signals(player, blacklist=("notify", "error"))
+            sigs = _map_signals(player, blacklist=("notify",))
             for event, handle in sigs:
                 def cb_handler(librarian, *args):
                     self.__invoke(librarian, args[-1], *args[:-1])
@@ -90,7 +93,7 @@ class EventPluginHandler(object):
         if args and args[0]:
             if isinstance(args[0], dict):
                 args[0] = SongWrapper(args[0])
-            elif isinstance(args[0], list):
+            elif isinstance(args[0], (set, list)):
                 args[0] = ListWrapper(args[0])
         for plugin in self.__plugins.itervalues():
             method_name = 'plugin_on_' + event.replace('-', '_')
@@ -104,16 +107,16 @@ class EventPluginHandler(object):
         if event not in ["removed", "changed"] and args:
             from quodlibet import app
             songs = args[0]
-            if not isinstance(songs, list):
+            if not isinstance(songs, (set, list)):
                 songs = [songs]
             songs = filter(None, songs)
             check_wrapper_changed(librarian, app.window, songs)
 
     def plugin_handle(self, plugin):
-        return issubclass(plugin, EventPlugin)
+        return issubclass(plugin.cls, EventPlugin)
 
-    def plugin_enable(self, plugin, obj):
-        self.__plugins[plugin] = obj
+    def plugin_enable(self, plugin):
+        self.__plugins[plugin.cls] = plugin.get_instance()
 
     def plugin_disable(self, plugin):
-        self.__plugins.pop(plugin)
+        self.__plugins.pop(plugin.cls)
