@@ -16,7 +16,7 @@ from quodlibet.qltk.views import RCMHintedTreeView
 
 
 def MenuItems(marks, player, seekable):
-    sizes = Gtk.SizeGroup(Gtk.SizeGroupMode.HORIZONTAL)
+    sizes = Gtk.SizeGroup(mode=Gtk.SizeGroupMode.HORIZONTAL)
     items = []
     if not marks or marks[0][0] != 0:
         # Translators: Refers to the beginning of the playing song.
@@ -64,7 +64,7 @@ class EditBookmarksPane(Gtk.VBox):
         sw = Gtk.ScrolledWindow()
         sw.set_shadow_type(Gtk.ShadowType.IN)
         sw.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
-        sw.add(RCMHintedTreeView(model))
+        sw.add(RCMHintedTreeView(model=model))
 
         render = Gtk.CellRendererText()
 
@@ -119,7 +119,7 @@ class EditBookmarksPane(Gtk.VBox):
         name.set_text(_("Bookmark Name"))
 
         menu = Gtk.Menu()
-        remove = Gtk.ImageMenuItem(Gtk.STOCK_REMOVE, use_stock=True)
+        remove = Gtk.ImageMenuItem(label=Gtk.STOCK_REMOVE, use_stock=True)
         remove.connect('activate', self.__remove, selection, library, song)
         keyval, mod = Gtk.accelerator_parse("Delete")
         remove.add_accelerator(
@@ -172,9 +172,10 @@ class EditBookmarksPane(Gtk.VBox):
         remove.set_sensitive(bool(selection.get_selected_rows()[1]))
 
     def __remove(self, remove, selection, library, song):
-        model, rows = selection.get_selected_rows()
+        model, paths = selection.get_selected_rows()
         if model:
-            map(model.remove, map(model.get_iter, rows))
+            for path in paths:
+                model.remove(model.get_iter(path))
             self.__set_bookmarks(model, None, None, library, song)
 
     def __set_bookmarks(self, model, a, b, library, song):
@@ -200,19 +201,18 @@ class EditBookmarks(qltk.Window):
         self.set_default_size(350, 250)
         self.set_title(_("Bookmarks") + " - %s" % player.song.comma("title"))
 
-        self.add(EditBookmarksPane(library, player.song, close=True))
+        pane = EditBookmarksPane(library, player.song, close=True)
+        self.add(pane)
 
         s = library.connect('removed', self.__check_lock, player.song)
         self.connect_object('destroy', library.disconnect, s)
 
         position = player.get_position() // 1000
-        self.get_child().time.set_text(util.format_time(position))
-        self.get_child().markname.grab_focus()
+        pane.time.set_text(util.format_time(position))
+        pane.markname.grab_focus()
+        pane.close.connect('clicked', lambda *x: self.destroy())
 
-        self.get_child().close.connect_object('clicked',
-                                              qltk.Window.destroy, self)
-
-        self.show_all()
+        self.get_child().show_all()
 
     def __check_lock(self, library, songs, song):
         if song in songs:
