@@ -8,6 +8,8 @@ from gi.repository import Gtk, Pango
 
 from quodlibet import config
 from quodlibet import util
+from quodlibet import qltk
+from quodlibet import browsers
 
 from quodlibet.qltk.songlist import SongList
 from quodlibet.qltk.x import Window, RPaned
@@ -15,24 +17,56 @@ from quodlibet.qltk.window import PersistentWindowMixin
 from quodlibet.util.library import background_filter
 
 
-class LibraryBrowser(Window, PersistentWindowMixin):
+class LibraryBrowser(Window, util.InstanceTracker, PersistentWindowMixin):
+
+    @classmethod
+    def open(cls, Kind, library):
+        """Creates and shows a new browser instance"""
+
+        browser = cls(Kind, library)
+        browser.show()
+        return browser
+
+    @classmethod
+    def save(cls):
+        """See which browser windows are open and save their names
+        so we can restore them on start.
+        """
+
+        names = []
+        for browser in cls.instances():
+            names.append(browser.name)
+        config.set("memory", "open_browsers", "\n".join(names))
+
+    @classmethod
+    def restore(cls, library):
+        """restore saved browser windows"""
+
+        value = config.get("memory", "open_browsers", "")
+        for name in value.split():
+            kind = browsers.get(name)
+            browser = cls(kind, library)
+            browser.show_maybe()
+
     def __init__(self, Kind, library):
         super(LibraryBrowser, self).__init__(dialog=False)
+        self._register_instance()
+        self.name = Kind.__name__
+
         self.set_default_size(600, 400)
-        self.enable_window_tracking("browser_" + Kind.__name__)
+        self.enable_window_tracking("browser_" + self.name)
         self.set_border_width(6)
         self.set_title(Kind.name + " - Quod Libet")
         self.add(Gtk.VBox(spacing=6))
 
         view = SongList(library, update=True)
         view.info.connect("changed", self.__set_time)
-        self.add_accel_group(view.accelerators)
         self.songlist = view
 
         sw = Gtk.ScrolledWindow()
         sw.set_shadow_type(Gtk.ShadowType.IN)
         sw.add(view)
-        sw.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.ALWAYS)
+        sw.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
 
         self.browser = browser = Kind(library, False)
         if browser.reordered:
@@ -64,23 +98,18 @@ class LibraryBrowser(Window, PersistentWindowMixin):
         for c in self.get_child().get_children():
             c.show()
         self.get_child().show()
-        self.show()
         self.__set_pane_size()
 
     def __set_pane_size(self):
-        sub = self.__container
-        if not isinstance(self.__container, RPaned):
-            for child in self.__container.get_children():
-                if isinstance(child, RPaned):
-                    sub = child
-
-        if isinstance(sub, RPaned):
+        widgets = qltk.find_widgets(self.__container, RPaned)
+        if widgets:
+            paned = widgets[0]
             try:
                 key = "%s_pos" % self.browser.__class__.__name__
                 val = config.getfloat("browsers", key)
             except:
                 val = 0.4
-            sub.set_relative(val)
+            paned.set_relative(val)
 
     def __browser_cb(self, browser, songs, sorted):
         if browser.background:
@@ -98,7 +127,7 @@ class LibraryBrowser(Window, PersistentWindowMixin):
     def __drag_data_recv(self, view, *args):
         if callable(self.browser.reordered):
             self.browser.reordered(view)
-        view.set_sort_by(None, refresh=False)
+        view.clear_sort()
 
     def __cols_changed(self, view, browser):
         for header in view.get_columns():
