@@ -29,11 +29,11 @@ from quodlibet.qltk.entry import UndoEntry
 from quodlibet.qltk.about import AboutExFalso
 from quodlibet.qltk.songsmenu import SongsMenuPluginHandler
 from quodlibet.qltk.x import Alignment, SeparatorMenuItem, ConfigRHPaned
-from quodlibet.qltk.window import PersistentWindowMixin
+from quodlibet.qltk.window import PersistentWindowMixin, Window
 from quodlibet.util.path import mtime, normalize_path
 
 
-class ExFalsoWindow(Gtk.Window, PersistentWindowMixin):
+class ExFalsoWindow(Window, PersistentWindowMixin):
     __gsignals__ = {
         'changed': (GObject.SignalFlags.RUN_LAST,
                     None, (object,)),
@@ -48,7 +48,7 @@ class ExFalsoWindow(Gtk.Window, PersistentWindowMixin):
         PluginManager.instance.register_handler(cls.pm)
 
     def __init__(self, library, dir=None):
-        super(ExFalsoWindow, self).__init__()
+        super(ExFalsoWindow, self).__init__(dialog=False)
         self.set_title("Ex Falso")
         self.set_default_size(750, 475)
         self.enable_window_tracking("exfalso")
@@ -103,6 +103,7 @@ class ExFalsoWindow(Gtk.Window, PersistentWindowMixin):
         hp.pack1(vb, resize=True, shrink=False)
 
         nb = qltk.Notebook()
+        nb.props.scrollable = True
         nb.show()
         for Page in [EditTags, TagsFromPath, RenameFiles, TrackNumbers]:
             page = Page(self, self.__library)
@@ -156,8 +157,8 @@ class ExFalsoWindow(Gtk.Window, PersistentWindowMixin):
     def __popup_menu(self, view, fs):
 
         # get all songs for the selection
-        filenames = fs.get_selected_paths()
-        filenames = map(normalize_path, map(os.path.realpath, filenames))
+        filenames = [normalize_path(f, canonicalise=True)
+                     for f in fs.get_selected_paths()]
         maybe_songs = [self.__library.get(f) for f in filenames]
         songs = [s for s in maybe_songs if s]
 
@@ -192,7 +193,7 @@ class ExFalsoWindow(Gtk.Window, PersistentWindowMixin):
         label.set_text(ngettext("%d song", "%d songs", count) % count)
 
         for row in rows:
-            filename = util.fsnative(model[row][0])
+            filename = model[row][0]
             if not os.path.exists(filename):
                 pass
             elif filename in self.__library:
@@ -242,7 +243,9 @@ class PreferencesWindow(qltk.UniqueWindow):
         hb.pack_start(l, False, True, 0)
         hb.pack_start(e, True, True, 0)
         cb = ConfigCheckButton(
-            _("Show _programmatic tags"), 'editing', 'alltags')
+            _("Show _programmatic tags"), 'editing', 'alltags',
+            tooltip=_("Access all tags, including machine-generated "
+                      "ones e.g. MusicBrainz or Replay Gain tags"))
         cb.set_active(config.getboolean("editing", 'alltags'))
         vbox.pack_start(hb, False, True, 0)
         vbox.pack_start(cb, False, True, 0)
