@@ -23,7 +23,8 @@ from quodlibet.qltk.views import TreeViewColumn
 from quodlibet.qltk.x import ScrolledWindow
 from quodlibet.qltk.models import ObjectStore, ObjectTreeStore
 
-from quodlibet.util.path import fsdecode, listdir
+from quodlibet.util.path import fsdecode, listdir, is_fsnative, glib2fsnative
+from quodlibet.util.uri import URI
 
 
 def search_func(model, column, key, iter_, handledirs):
@@ -99,7 +100,7 @@ def _get_win_drives():
     """Returns a list of paths for all available drives e.g. ['C:\\']"""
 
     assert os.name == "nt"
-    drives = [letter + ":\\" for letter in "CDEFGHIJKLMNOPQRSTUVWXYZ"]
+    drives = [letter + u":\\" for letter in u"CDEFGHIJKLMNOPQRSTUVWXYZ"]
     return [d for d in drives if os.path.isdir(d)]
 
 
@@ -118,6 +119,9 @@ def get_gtk_bookmarks():
     The paths don't have to exist.
     """
 
+    if os.name == "nt":
+        return []
+
     path = os.path.join(const.HOME, ".gtk-bookmarks")
     folders = []
     try:
@@ -148,7 +152,7 @@ class DirectoryTree(RCMTreeView, MultiDragTreeView):
         super(DirectoryTree, self).__init__(model=model)
 
         if initial is not None:
-            initial = util.fsnative(initial)
+            assert is_fsnative(initial)
 
         column = TreeViewColumn(_("Folders"))
         column.set_sizing(Gtk.TreeViewColumnSizing.AUTOSIZE)
@@ -168,6 +172,7 @@ class DirectoryTree(RCMTreeView, MultiDragTreeView):
 
         self.append_column(column)
         self.set_search_equal_func(search_func, True)
+        self.set_search_column(0)
 
         if folders is None:
             folders = []
@@ -175,6 +180,7 @@ class DirectoryTree(RCMTreeView, MultiDragTreeView):
         for path in folders:
             niter = model.append(None, [path])
             if path is not None:
+                assert is_fsnative(path)
                 model.append(niter, ["dummy"])
 
         self.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
@@ -203,6 +209,14 @@ class DirectoryTree(RCMTreeView, MultiDragTreeView):
         menu.show_all()
         self.connect_object('popup-menu', self.__popup_menu, menu)
 
+        # Allow to drag and drop files from outside
+        targets = [
+            ("text/uri-list", 0, 42)
+        ]
+        targets = [Gtk.TargetEntry.new(*t) for t in targets]
+        self.drag_dest_set(Gtk.DestDefaults.ALL, targets, Gdk.DragAction.COPY)
+        self.connect('drag-data-received', self.__drag_data_received)
+
     def get_selected_paths(self):
         """A list of fs paths"""
 
@@ -211,18 +225,15 @@ class DirectoryTree(RCMTreeView, MultiDragTreeView):
         return [model[p][0] for p in paths]
 
     def go_to(self, path_to_go):
-        # FIXME: be stricter here..
-        # assert util.is_fsnative(path_to_go)
+        assert util.is_fsnative(path_to_go)
 
         # FIXME: what about non-normalized paths?
-
-        path_to_go = util.fsnative(path_to_go)
         model = self.get_model()
 
         # Find the top level row which has the largest common
         # path with the path we want to go to
         roots = dict([(p, i) for (i, p) in model.iterrows(None)])
-        head, tail = path_to_go, util.fsnative("")
+        head, tail = path_to_go, util.fsnative(u"")
         to_find = []
         while head and head not in roots:
             new_head, tail = os.path.split(head)
@@ -261,6 +272,20 @@ class DirectoryTree(RCMTreeView, MultiDragTreeView):
 
         search(self, model, start_iter, to_find)
 
+    def __drag_data_received(self, widget, drag_ctx, x, y, data, info, time):
+        if info == 42:
+            uris = data.get_uris()
+            if uris:
+                try:
+                    filename = URI(uris[0]).filename
+                except ValueError:
+                    pass
+                else:
+                    self.go_to(filename)
+                    Gtk.drag_finish(drag_ctx, True, False, time)
+                    return
+        Gtk.drag_finish(drag_ctx, False, False, time)
+
     def __popup_menu(self, menu):
         model, paths = self.get_selection().get_selected_rows()
         if len(paths) != 1:
@@ -295,7 +320,7 @@ class DirectoryTree(RCMTreeView, MultiDragTreeView):
         if not dir_:
             return
 
-        dir_ = util.fsnative(dir_.decode('utf-8'))
+        dir_ = glib2fsnative(dir_)
         fullpath = os.path.realpath(os.path.join(directory, dir_))
 
         try:
@@ -425,14 +450,14 @@ class FileSelector(Gtk.VPaned):
         self.__filter = filter
 
         if initial is not None:
-            initial = util.fsnative(initial)
+            assert is_fsnative(initial)
 
         if initial and os.path.isfile(initial):
             initial = os.path.dirname(initial)
         dirlist = DirectoryTree(initial, folders=folders)
 
         model = ObjectStore()
-        filelist = AllTreeView(model)
+        filelist = AllTreeView(model=model)
 
         column = TreeViewColumn(_("Songs"))
         column.set_sizing(Gtk.TreeViewColumnSizing.AUTOSIZE)
@@ -453,6 +478,7 @@ class FileSelector(Gtk.VPaned):
         filelist.set_rules_hint(True)
         filelist.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
         filelist.set_search_equal_func(search_func, False)
+        filelist.set_search_column(0)
 
         self.__sig = filelist.get_selection().connect(
             'changed', self.__changed)
