@@ -5,6 +5,7 @@
 # published by the Free Software Foundation
 
 from gi.repository import Gtk
+from quodlibet import app
 
 from quodlibet.qltk import get_top_parent
 
@@ -19,9 +20,8 @@ class Message(Gtk.MessageDialog):
         text = ("<span weight='bold' size='larger'>%s</span>\n\n%s"
                 % (title, description))
         super(Message, self).__init__(
-            parent,
-            Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-            kind, buttons)
+            transient_for=parent, modal=True, destroy_with_parent=True,
+            message_type=kind, buttons=buttons)
         self.set_markup(text)
 
     def run(self, destroy=True):
@@ -50,6 +50,11 @@ class ConfirmAction(Message):
             return False
 
 
+def confirm_action(msg):
+    """Ultra-lightweight confirmation dialog"""
+    return ConfirmAction(app.window, _("Are you sure?"), msg).run()
+
+
 class CancelRevertSave(Gtk.MessageDialog):
     def __init__(self, parent):
         title = _("Discard tag changes?")
@@ -59,7 +64,8 @@ class CancelRevertSave(Gtk.MessageDialog):
                 % (title, description))
         parent = get_top_parent(parent)
         super(CancelRevertSave, self).__init__(
-            parent, flags=0, type=Gtk.MessageType.WARNING,
+            transient_for=parent, flags=0,
+            message_type=Gtk.MessageType.WARNING,
             buttons=Gtk.ButtonsType.NONE)
         self.add_buttons(Gtk.STOCK_SAVE, Gtk.ResponseType.YES,
                          Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
@@ -84,4 +90,4 @@ class WarningMessage(Message):
     """Like Message, but uses an warning-indicating picture."""
     def __init__(self, *args, **kwargs):
         super(WarningMessage, self).__init__(
-            Gtk.MessageType.ERROR, *args, **kwargs)
+            Gtk.MessageType.WARNING, *args, **kwargs)
