@@ -37,69 +37,75 @@ from quodlibet.qltk.pluginwin import PluginWindow
 from quodlibet.qltk.properties import SongProperties
 from quodlibet.qltk.prefs import PreferencesWindow
 from quodlibet.qltk.queue import QueueExpander
-from quodlibet.qltk.songlist import SongList
+from quodlibet.qltk.songlist import SongList, get_columns, set_columns
 from quodlibet.qltk.songmodel import PlaylistMux
 from quodlibet.qltk.x import RPaned, ConfigRVPaned, Alignment, ScrolledWindow
+from quodlibet.qltk.x import SymbolicIconImage
 from quodlibet.qltk.about import AboutQuodLibet
 from quodlibet.util import copool, gobject_weak
 from quodlibet.util.library import get_scan_dirs, set_scan_dirs
 from quodlibet.util.uri import URI
+from quodlibet.util.path import glib2fsnative
 from quodlibet.util.library import background_filter, scan_library
-from quodlibet.qltk.window import PersistentWindowMixin
+from quodlibet.qltk.window import PersistentWindowMixin, Window
+from quodlibet.qltk.songlistcolumns import SongListColumn
+
+
+class CurrentColumn(SongListColumn):
+    """Displays the current song indicator, either a play or pause icon."""
+
+    def __init__(self):
+        super(CurrentColumn, self).__init__("~current")
+        self._render = Gtk.CellRendererPixbuf(follow_state=True)
+        self.pack_start(self._render, True)
+        self._render.set_property('xalign', 0.5)
+
+        self.set_fixed_width(24)
+        self.set_expand(False)
+        self.set_cell_data_func(self._render, self._cdf)
+
+    def _format_title(self, tag):
+        return u""
+
+    def _cdf(self, column, cell, model, iter_, user_data):
+        PLAY = "media-playback-start"
+        PAUSE = "media-playback-pause"
+        STOP = "media-playback-stop"
+        ERROR = "dialog-error"
+
+        row = model[iter_]
+
+        if row.path == model.current_path:
+            player = app.player
+            if player.error:
+                name = ERROR
+            elif model.sourced:
+                name = [PLAY, PAUSE][player.paused]
+            else:
+                name = STOP
+        else:
+            name = None
+
+        if not self._needs_update(name):
+            return
+
+        if name is not None:
+            gicon = Gio.ThemedIcon.new_from_names(
+                [name + "-symbolic", name])
+        else:
+            gicon = None
+
+        cell.set_property('gicon', gicon)
 
 
 class MainSongList(SongList):
     # The SongList that represents the current playlist.
 
-    class CurrentColumn(Gtk.TreeViewColumn):
-        # Displays the current song indicator, either a play or pause icon.
-        header_name = "~current"
-        __last_name = None
-
-        def _cdf(self, column, cell, model, iter, data):
-            PLAY = "media-playback-start"
-            PAUSE = "media-playback-pause"
-            STOP = "media-playback-stop"
-            ERROR = "dialog-error"
-
-            row = model[iter]
-            song = row[0]
-
-            if row.path == model.current_path:
-                if model.sourced:
-                    name = [PLAY, PAUSE][app.player.paused]
-                else:
-                    name = STOP
-            elif song("~errors"):
-                name = ERROR
-            else:
-                name = None
-
-            if self.__last_name == name:
-                return
-            self.__last_name = name
-
-            if name is not None:
-                gicon = Gio.ThemedIcon.new_from_names(
-                    [name + "-symbolic", name])
-            else:
-                gicon = None
-
-            cell.set_property('gicon', gicon)
-
-        def __init__(self):
-            self._render = Gtk.CellRendererPixbuf()
-            self._render.set_property('xalign', 0.5)
-            super(MainSongList.CurrentColumn, self).__init__("", self._render)
-            self.set_sizing(Gtk.TreeViewColumnSizing.FIXED)
-            self.set_fixed_width(24)
-            self.set_cell_data_func(self._render, self._cdf)
-            self.header_name = "~current"
-
     _activated = False
 
     def __init__(self, library, player):
         super(MainSongList, self).__init__(library, player, update=True)
+        self.set_first_column_type(CurrentColumn)
 
         self.connect_object('row-activated', self.__select_song, player)
 
@@ -110,17 +116,20 @@ class MainSongList(SongList):
         s = player.connect_after('song-started', reset_activated)
         self.connect_object('destroy', player.disconnect, s)
 
+        self.connect("orders-changed", self.__orders_changed)
+
+    def __orders_changed(self, *args):
+        l = []
+        for tag, reverse in self.get_sort_orders():
+            l.append("%d%s" % (int(reverse), tag))
+        config.setstringlist('memory', 'sortby', l)
+
     def __select_song(self, player, indices, col):
         self._activated = True
         iter = self.model.get_iter(indices)
         if player.go_to(iter, True):
             player.paused = False
 
-    def set_sort_by(self, *args, **kwargs):
-        super(MainSongList, self).set_sort_by(*args, **kwargs)
-        tag, reverse = self.get_sort_by()
-        config.set('memory', 'sortby', "%d%s" % (int(reverse), tag))
-
 
 class SongListScroller(ScrolledWindow):
     def __init__(self, menu):
@@ -153,11 +162,12 @@ class TopBar(Gtk.Toolbar):
         info_item.set_expand(True)
 
         box = Gtk.Box(spacing=6)
-        info_item.add(Alignment(box, border=3, right=-3))
+        info_item.add(box)
+        qltk.add_css(self, "GtkToolbar {padding: 3px;}")
 
         # song text
         text = SongInfo(library.librarian, player)
-        box.pack_start(Alignment(text, top=3, bottom=3), True, True, 0)
+        box.pack_start(Alignment(text, border=3), True, True, 0)
 
         # cover image
         self.image = CoverImage(resize=True)
@@ -165,7 +175,11 @@ class TopBar(Gtk.Toolbar):
                      parent=self)
         gobject_weak(parent.connect, 'artwork-changed',
                      self.__song_art_changed, library, parent=self)
-        box.pack_start(self.image, False, True, 0)
+
+        # CoverImage doesn't behave in a Alignment, so wrap it
+        coverbox = Gtk.Box()
+        coverbox.pack_start(self.image, True, True, 0)
+        box.pack_start(Alignment(coverbox, border=2), False, True, 0)
 
         for child in self.get_children():
             child.show_all()
@@ -189,27 +203,46 @@ class TopBar(Gtk.Toolbar):
             library.albums.refresh(refresh_albums)
 
 
+class ReapeatButton(Gtk.ToggleButton):
+
+    def __init__(self):
+        super(ReapeatButton, self).__init__(
+            image=SymbolicIconImage(
+                "media-playlist-repeat", Gtk.IconSize.SMALL_TOOLBAR))
+
+        self.set_name("ql-repeat-button")
+        qltk.add_css(self, """
+            #ql-repeat-button {
+                padding: 0px;
+            }
+        """)
+        self.set_size_request(26, 26)
+
+        self.set_tooltip_text(_("Restart the playlist when finished"))
+
+        self.bind_config("settings", "repeat")
+
+    def bind_config(self, section, option):
+        self.set_active(config.getboolean(section, option))
+
+        def toggled_cb(*args):
+            config.set(section, option, self.get_active())
+
+        self.connect('toggled', toggled_cb)
+
+
 class StatusBarBox(Gtk.HBox):
+
     def __init__(self, model, player):
-        super(StatusBarBox, self).__init__(spacing=12)
+        super(StatusBarBox, self).__init__(spacing=6)
 
         self.order = order = PlayOrder(model, player)
+        self.pack_start(order, False, True, 0)
 
-        hb = Gtk.HBox(spacing=6)
-        label = Gtk.Label(label=_("_Order:"))
-        label.set_mnemonic_widget(order)
-        label.set_use_underline(True)
-        hb.pack_start(label, True, True, 0)
-        hb.pack_start(order, True, True, 0)
-        self.pack_start(hb, False, True, 0)
-
-        self.repeat = repeat = qltk.ccb.ConfigCheckButton(
-            _("_Repeat"), "settings", "repeat")
-        repeat.set_tooltip_text(_("Restart the playlist when finished"))
+        self.repeat = repeat = ReapeatButton()
         self.pack_start(repeat, False, True, 0)
-
         repeat.connect('toggled', self.__repeat, model)
-        repeat.set_active(config.getboolean('settings', 'repeat'))
+        model.repeat = repeat.get_active()
 
         self.statusbar = StatusBar(TaskController.default_instance)
         self.pack_start(self.statusbar, True, True, 0)
@@ -280,6 +313,15 @@ class AppMenu(object):
         am_object_path = "/net/sacredchao/QuodLibet/menus/appmenu"
         app_id = "net.sacredchao.QuodLibet"
 
+        win = window.get_window()
+        if not hasattr(win, "set_utf8_property"):
+            # not a GdkX11.X11Window
+            print_d("Registering appmenu failed: X11 only")
+            return
+
+        # FIXME: this doesn't fail on Windows but takes for ages.
+        # Maybe remove some deps to make it fail fast?
+        # We don't need dbus anyway there.
         try:
             bus = Gio.bus_get_sync(Gio.BusType.SESSION, None)
             self._ag_id = bus.export_action_group(ag_object_path, action_group)
@@ -290,12 +332,6 @@ class AppMenu(object):
 
         self._bus = bus
 
-        win = window.get_window()
-        if not hasattr(win, "set_utf8_property"):
-            # not a GdkX11.X11Window
-            print_d("Registering appmenu failed: X11 only")
-            return
-
         win.set_utf8_property("_GTK_UNIQUE_BUS_NAME", bus.get_unique_name())
         win.set_utf8_property("_GTK_APPLICATION_ID", app_id)
         win.set_utf8_property("_GTK_APPLICATION_OBJECT_PATH", ag_object_path)
@@ -308,17 +344,30 @@ class AppMenu(object):
             self._bus = None
 
 
+class PlaybackErrorDialog(ErrorMessage):
+
+    def __init__(self, parent, player_error):
+        add_full_stop = lambda s: s and (s.rstrip(".") + ".")
+        description = add_full_stop(util.escape(player_error.short_desc))
+        details = add_full_stop(util.escape(player_error.long_desc or ""))
+        if details:
+            description += " " + details
+
+        super(PlaybackErrorDialog, self).__init__(
+            parent, _("Playback Error"), description)
+
+
 DND_URI_LIST, = range(1)
 
 
-class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
+class QuodLibetWindow(Window, PersistentWindowMixin):
     SIG_PYOBJECT = (GObject.SignalFlags.RUN_LAST, None, (object,))
     __gsignals__ = {
         'artwork-changed': SIG_PYOBJECT,
     }
 
     def __init__(self, library, player, headless=False):
-        super(QuodLibetWindow, self).__init__()
+        super(QuodLibetWindow, self).__init__(dialog=False)
         self.last_dir = const.HOME
 
         self.__update_title(player)
@@ -370,7 +419,7 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
         self.statusbar = statusbox.statusbar
 
         main_box.pack_start(
-            Alignment(statusbox, border=3, top=-3, left=6, right=6),
+            Alignment(statusbox, border=3, top=-3, right=3),
             False, True, 0)
 
         self.songpane = ConfigRVPaned("memory", "queue_position", 0.75)
@@ -378,14 +427,36 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
         self.songpane.pack2(self.qexpander, resize=True, shrink=False)
         self.__handle_position = self.songpane.get_property("position")
 
+        def songpane_button_press_cb(pane, event):
+            """If we start to drag the pane handle while the
+            queue expander is unexpanded, expand it and move the handle
+            to the bottom, so we can 'drag' the queue out
+            """
+
+            if event.window != pane.get_handle_window():
+                return False
+
+            if not self.qexpander.get_expanded():
+                self.qexpander.set_expanded(True)
+                pane.set_relative(1.0)
+            return False
+
+        self.songpane.connect("button-press-event", songpane_button_press_cb)
+
         self.song_scroller.connect('notify::visible', self.__show_or)
         self.qexpander.connect('notify::visible', self.__show_or)
         self.qexpander.connect('notify::expanded', self.__expand_or)
         self.qexpander.connect('draw', self.__qex_size_allocate)
         self.songpane.connect('notify', self.__moved_pane_handle)
 
-        sort = config.get('memory', 'sortby')
-        self.songlist.set_sort_by(None, sort[1:], order=int(sort[0]))
+        try:
+            orders = []
+            for e in config.getstringlist('memory', 'sortby', []):
+                orders.append((e[1:], int(e[0])))
+        except ValueError:
+            pass
+        else:
+            self.songlist.set_sort_orders(orders)
 
         self.browser = None
         self.ui = ui
@@ -422,6 +493,7 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
         gobject_weak(lib.connect_object, 'changed', self.__song_changed,
                      player, parent=self)
 
+        self._playback_error_dialog = None
         player_sigs = [
             ('song-started', self.__song_started),
             ('paused', self.__update_paused, True),
@@ -430,6 +502,11 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
         for sig in player_sigs:
             gobject_weak(player.connect, *sig, **{"parent": self})
 
+        # make sure we redraw all error indicators before opening
+        # a dialog (blocking the main loop), so connect after default handlers
+        gobject_weak(player.connect_after, 'error',
+                     self.__player_error, **{"parent": self})
+
         # connect after to let SongTracker update stats
         player_sigs.append(
             gobject_weak(player.connect_after, "song-ended",
@@ -455,6 +532,15 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
 
         self.enable_window_tracking("quodlibet")
 
+    def __player_error(self, player, song, player_error):
+        # it's modal, but mmkeys etc. can still trigger new ones
+        if self._playback_error_dialog:
+            self._playback_error_dialog.destroy()
+        dialog = PlaybackErrorDialog(self, player_error)
+        self._playback_error_dialog = dialog
+        dialog.run()
+        self._playback_error_dialog = None
+
     def __configure_scan_dirs(self, library):
         """Get user to configure scan dirs, if none is set up"""
         if not get_scan_dirs() and not len(library) and \
@@ -548,7 +634,7 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
     def __songlist_drag_data_recv(self, view, *args):
         if callable(self.browser.reordered):
             self.browser.reordered(view)
-        self.songlist.set_sort_by(None, refresh=False)
+        self.songlist.clear_sort()
 
     def __save_browser(self, *args):
         print_d("Saving active browser state")
@@ -585,7 +671,7 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
                 self.songpane.set_property("position", p_max)
 
     def __create_menu(self, player, library):
-        ag = Gtk.ActionGroup('QuodLibetWindowActions')
+        ag = Gtk.ActionGroup.new('QuodLibetWindowActions')
 
         def logging_cb(*args):
             window = LoggingWindow(self)
@@ -642,36 +728,38 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
 
         ag.add_actions(actions)
 
-        act = Gtk.ToggleAction("StopAfter",
-                               _("Stop After This Song"), None, "")
+        act = Gtk.ToggleAction.new("StopAfter",
+                                   _("Stop After This Song"), None, "")
         ag.add_action_with_accel(act, "<shift>space")
 
         # access point for the tray icon
         self.stop_after = act
 
-        act = Gtk.Action("AddBookmark", _("Add Bookmark"), None, Gtk.STOCK_ADD)
+        act = Gtk.Action.new(
+            "AddBookmark", _("Add Bookmark"), None, Gtk.STOCK_ADD)
         act.connect_object('activate', self.__add_bookmark,
                            library.librarian, player)
         ag.add_action_with_accel(act, "<ctrl>D")
 
-        act = Gtk.Action("EditBookmarks", _(u"Edit Bookmarks…"), None, "")
+        act = Gtk.Action.new("EditBookmarks", _(u"Edit Bookmarks…"), None, "")
         act.connect_object('activate', self.__edit_bookmarks,
                            library.librarian, player)
         ag.add_action_with_accel(act, "<ctrl>B")
 
-        act = Gtk.Action("About", None, None, Gtk.STOCK_ABOUT)
+        act = Gtk.Action.new("About", None, None, Gtk.STOCK_ABOUT)
         act.connect_object('activate', self.__show_about, player)
         ag.add_action_with_accel(act, None)
 
-        act = Gtk.Action("OnlineHelp", _("Online Help"), None, Gtk.STOCK_HELP)
+        act = Gtk.Action.new(
+            "OnlineHelp", _("Online Help"), None, Gtk.STOCK_HELP)
         act.connect_object('activate', util.website, const.ONLINE_HELP)
         ag.add_action_with_accel(act, "F1")
 
-        act = Gtk.Action("SearchHelp", _("Search Help"), None, "")
+        act = Gtk.Action.new("SearchHelp", _("Search Help"), None, "")
         act.connect_object('activate', util.website, const.SEARCH_HELP)
         ag.add_action_with_accel(act, None)
 
-        act = Gtk.Action(
+        act = Gtk.Action.new(
             "RefreshLibrary", _("Re_fresh Library"), None, Gtk.STOCK_REFRESH)
         act.connect('activate', self.__rebuild, False)
         ag.add_action_with_accel(act, None)
@@ -680,7 +768,7 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
             ("genre", _("Filter on _Genre")),
             ("artist", _("Filter on _Artist")),
             ("album", _("Filter on Al_bum"))]:
-            act = Gtk.Action(
+            act = Gtk.Action.new(
                 "Filter%s" % util.capitalize(tag_), lab, None, Gtk.STOCK_INDEX)
             act.connect_object('activate',
                                self.__filter_on, tag_, None, player)
@@ -690,8 +778,8 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
             ("genre", "G", _("Random _Genre")),
             ("artist", "T", _("Random _Artist")),
             ("album", "M", _("Random Al_bum"))]:
-            act = Gtk.Action("Random%s" % util.capitalize(tag_), label,
-                             None, Gtk.STOCK_DIALOG_QUESTION)
+            act = Gtk.Action.new("Random%s" % util.capitalize(tag_), label,
+                                 None, Gtk.STOCK_DIALOG_QUESTION)
             act.connect('activate', self.__random, tag_)
             ag.add_action_with_accel(act, "<control>" + accel)
 
@@ -922,36 +1010,29 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
         from an event like song-started.
         """
 
-        def jump_to(song, select=True):
-            model = self.songlist.model
-            if song == model.current:
-                path = model.current_path
-            else:
-                iter = model.find(song)
-                if iter is None:
-                    return
-                path = model[iter].path
-
-            self.songlist.scroll_to_cell(path, use_align=True, row_align=0.5)
-            if select:
-                self.songlist.set_cursor(path)
+        def idle_jump_to(song, select):
+            ok = self.songlist.jump_to_song(song, select=select)
+            if ok:
+                self.songlist.grab_focus()
+            return False
 
         song = app.player.song
-        model = self.songlist.model
 
         # We are not playing a song
         if song is None:
             return
 
-        # model.find because the source could be the queue
-        if song == model.current or (model.find(song) and explicit):
-            jump_to(song, select=explicit)
+        ok = self.songlist.jump_to_song(song, select=explicit)
+        if ok:
+            self.songlist.grab_focus()
         elif explicit:
-            self.browser.scroll(app.player.song)
+            # if we can't find it and the user requested it, try harder
+            self.browser.scroll(song)
             # We need to wait until the browser has finished
             # scrolling/filling and the songlist is ready.
             # Not perfect, but works for now.
-            GLib.idle_add(jump_to, song, priority=GLib.PRIORITY_LOW)
+            GLib.idle_add(
+                idle_jump_to, song, explicit, priority=GLib.PRIORITY_LOW)
 
     def __next_song(self, *args):
         app.player.next()
@@ -1045,6 +1126,7 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
             fns, do_watch = dialog.run()
             dialog.destroy()
             if fns:
+                fns = map(glib2fsnative, fns)
                 # scan them
                 self.last_dir = fns[0]
                 copool.add(self.__library.scan, fns, funcid="library")
@@ -1061,8 +1143,9 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
             fns = dialog.run()
             dialog.destroy()
             if fns:
+                fns = map(glib2fsnative, fns)
                 self.last_dir = os.path.dirname(fns[0])
-                for filename in map(os.path.realpath, map(util.fsnative, fns)):
+                for filename in map(os.path.realpath, fns):
                     self.__library.add_filename(filename)
 
     def __songs_popup_menu(self, songlist):
@@ -1149,9 +1232,9 @@ class QuodLibetWindow(Gtk.Window, PersistentWindowMixin):
             headers.remove('~current')
         except ValueError:
             pass
-        if len(headers) == len(config.get_columns()):
+        if len(headers) == len(get_columns()):
             # Not an addition or removal (handled separately)
-            config.set_columns(headers)
+            set_columns(headers)
             SongList.headers = headers
 
     def __make_query(self, query):
