@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2011, 2012 Nick Boultbee
+# Copyright 2011-2013 Nick Boultbee
 #           2005 Joe Wreschnig
 #
 # This program is free software; you can redistribute it and/or modify
@@ -11,6 +11,8 @@ from gi.repository import Gtk
 from quodlibet import util
 from quodlibet import config
 from quodlibet import qltk
+from quodlibet.config import RATINGS
+from quodlibet.qltk import SeparatorMenuItem
 
 
 class ConfirmRateMultipleDialog(qltk.Message):
@@ -19,12 +21,12 @@ class ConfirmRateMultipleDialog(qltk.Message):
 
         title = (_("Are you sure you want to change the "
                    "rating of all %d songs?") % count)
-        description = _("The rating of all selected songs will "
-                        "be changed to '%s'") % util.format_rating(value)
+        desc = (_("The saved ratings will be removed") if value is None
+                else _("The rating of all selected songs will be changed to "
+                       "'%s'") % util.format_rating(value))
 
         super(ConfirmRateMultipleDialog, self).__init__(
-            Gtk.MessageType.WARNING, parent, title, description,
-            Gtk.ButtonsType.NONE)
+            Gtk.MessageType.WARNING, parent, title, desc, Gtk.ButtonsType.NONE)
 
         self.add_buttons(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
                          Gtk.STOCK_APPLY, Gtk.ResponseType.YES)
@@ -42,15 +44,32 @@ class RatingsMenuItem(Gtk.MenuItem):
                 return
         for song in songs:
             song["~#rating"] = value
-        librarian.changed([song])
+        librarian.changed(songs)
+
+    def remove_rating(self, songs, librarian):
+        count = len(songs)
+        if (count > 1 and
+                config.getboolean("browsers", "rating_confirm_multiple")):
+            dialog = ConfirmRateMultipleDialog(self, count, None)
+            if dialog.run() != Gtk.ResponseType.YES:
+                return
+        reset = []
+        for song in songs:
+            if "~#rating" in song:
+                del song["~#rating"]
+                reset.append(song)
+        librarian.changed(reset)
 
     def __init__(self, songs, library, label=_("_Rating")):
         super(RatingsMenuItem, self).__init__(label=label, use_underline=True)
         submenu = Gtk.Menu()
         self.set_submenu(submenu)
-        for i in range(0, int(1.0 / util.RATING_PRECISION) + 1):
-            i *= util.RATING_PRECISION
-            itm = Gtk.MenuItem("%0.2f\t%s" % (i, util.format_rating(i)))
+        for i in RATINGS.all:
+            itm = Gtk.MenuItem(label="%0.2f\t%s" % (i, util.format_rating(i)))
             submenu.append(itm)
             itm.connect_object('activate', self.set_rating, i, songs, library)
+        reset = Gtk.MenuItem(label=_("_Remove rating"), use_underline=True)
+        reset.connect_object('activate', self.remove_rating, songs, library)
+        submenu.append(SeparatorMenuItem())
+        submenu.append(reset)
         submenu.show_all()
