@@ -1,26 +1,31 @@
 # Copyright 2006 Joe Wreschnig
+#      2013-2014 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 
-from gi.repository import Gtk, Gdk
+from gi.repository import Gtk
+from quodlibet.qltk.msg import confirm_action
 
 from quodlibet import qltk
 
 from quodlibet.util import print_exc
-from quodlibet.qltk.delete import DeleteDialog
+from quodlibet.qltk.delete import TrashMenuItem, trash_songs
 from quodlibet.qltk.information import Information
 from quodlibet.qltk.properties import SongProperties
 from quodlibet.qltk.x import SeparatorMenuItem
-from quodlibet.plugins import PluginManager
+from quodlibet.plugins import PluginManager, PluginHandler
 from quodlibet.plugins.songsmenu import SongsMenuPlugin
 from quodlibet.util.songwrapper import ListWrapper, check_wrapper_changed
 
 
-class SongsMenuPluginHandler(object):
-    def __init__(self):
+class SongsMenuPluginHandler(PluginHandler):
+
+    def __init__(self, confirmer):
         self.__plugins = []
+        # The method to call for confirmations of risky multi-invocations
+        self.confirm_multiple = confirmer
 
     def Menu(self, library, parent, songs):
         songs = ListWrapper(songs)
@@ -49,7 +54,7 @@ class SongsMenuPluginHandler(object):
                 try:
                     items.append(Kind(songs, library, parent))
                 except:
-                    print_e("Couldn't initalise song plugin %s. Stack trace:"
+                    print_e("Couldn't initialise song plugin %s. Stack trace:"
                             % Kind)
                     print_exc()
         items = filter(lambda i: i.initialized, items)
@@ -83,7 +88,8 @@ class SongsMenuPluginHandler(object):
             albums[key].append(song)
 
         albums = albums.values()
-        map(list.sort, albums)
+        for album in albums:
+            album.sort()
         return albums
 
     def handle(self, plugin_id, library, parent, songs):
@@ -114,6 +120,15 @@ class SongsMenuPluginHandler(object):
                     if ret:
                         return
             if callable(plugin.plugin_song):
+                total = len(songs)
+                if total > plugin.MAX_INVOCATIONS:
+                    msg = ngettext("Are you sure you want to run "
+                                       "the \"%s\" plugin on %d song?",
+                                   "Are you sure you want to run "
+                                       "the \"%s\" plugin on %d songs?",
+                                   total) % (plugin.PLUGIN_ID, total)
+                    if not self.confirm_multiple(msg):
+                        return
                 try:
                     ret = map(plugin.plugin_song, songs)
                 except Exception:
@@ -130,9 +145,17 @@ class SongsMenuPluginHandler(object):
                     if ret:
                         return
 
-            if max(map(callable, (plugin.plugin_single_album,
-                plugin.plugin_album, plugin.plugin_albums))):
+            if plugin.handles_albums:
                 albums = self.__get_albums(songs)
+                total = len(albums)
+                if total > plugin.MAX_INVOCATIONS:
+                    msg = ngettext("Are you sure you want to run "
+                                       "the \"%s\" plugin on %d album?",
+                                   "Are you sure you want to run "
+                                       "the \"%s\" plugin on %d albums?",
+                                   total) % (plugin.PLUGIN_ID, total)
+                    if not self.confirm_multiple(msg):
+                        return
 
             if callable(plugin.plugin_single_album) and len(albums) == 1:
                 try:
@@ -163,19 +186,17 @@ class SongsMenuPluginHandler(object):
             check_wrapper_changed(library, parent, filter(None, songs))
 
     def plugin_handle(self, plugin):
-        return issubclass(plugin, SongsMenuPlugin)
+        return issubclass(plugin.cls, SongsMenuPlugin)
 
-    def plugin_enable(self, plugin, obj):
-        self.__plugins.append(plugin)
+    def plugin_enable(self, plugin):
+        self.__plugins.append(plugin.cls)
 
     def plugin_disable(self, plugin):
-        self.__plugins.remove(plugin)
+        self.__plugins.remove(plugin.cls)
 
 
 class SongsMenu(Gtk.Menu):
-    __accels = Gtk.AccelGroup()
-
-    plugins = SongsMenuPluginHandler()
+    plugins = SongsMenuPluginHandler(confirm_action)
 
     @classmethod
     def init_plugins(cls):
@@ -183,7 +204,7 @@ class SongsMenu(Gtk.Menu):
 
     def __init__(self, library, songs, plugins=True, playlists=True,
                  queue=True, devices=True, remove=True, delete=False,
-                 edit=True, accels=None, parent=None):
+                 edit=True, parent=None):
         super(SongsMenu, self).__init__()
 
         # The library may actually be a librarian; if it is, use it,
@@ -218,23 +239,20 @@ class SongsMenu(Gtk.Menu):
 
             # FIXME: Two things are now importing browsers, so we need
             # some kind of inversion of control here.
-            from quodlibet import browsers
+            from quodlibet.browsers.playlists.menu import PlaylistMenu
             try:
-                submenu = browsers.playlists.Menu(songs, parent)
-            except AttributeError:
-                pass
+                submenu = PlaylistMenu(songs, parent)
+            except AttributeError as e:
+                print_w("Couldn't get Playlists menu: %s" % e)
             else:
-                b = qltk.MenuItem(_("_Add to Playlist"), Gtk.STOCK_ADD)
+                b = qltk.MenuItem(_("Play_lists"), Gtk.STOCK_ADD)
                 b.set_sensitive(can_add)
                 b.set_submenu(submenu)
                 self.append(b)
         if queue:
             b = qltk.MenuItem(_("Add to _Queue"), Gtk.STOCK_ADD)
             b.connect('activate', self.__enqueue, songs)
-            if accels is not None:
-                key, val = Gtk.accelerator_parse("<ctrl>Return")
-                b.add_accelerator(
-                    'activate', accels, key, val, Gtk.AccelFlags.VISIBLE)
+            qltk.add_fake_accel(b, "<ctrl>Return")
             self.append(b)
             b.set_sensitive(can_add)
 
@@ -252,7 +270,7 @@ class SongsMenu(Gtk.Menu):
                     b.set_submenu(submenu)
                     self.append(b)
 
-        if remove or delete or edit:
+        if remove or delete:
             self.separate()
 
         if remove:
@@ -265,30 +283,35 @@ class SongsMenu(Gtk.Menu):
             self.append(b)
 
         if delete:
-            b = Gtk.ImageMenuItem(Gtk.STOCK_DELETE, use_stock=True)
             if callable(delete):
+                b = Gtk.ImageMenuItem(Gtk.STOCK_DELETE, use_stock=True)
                 b.connect_object('activate', delete, songs)
             else:
-                b.connect('activate', self.__delete, songs, librarian)
+                b = TrashMenuItem()
+                b.connect_object('activate', trash_songs,
+                                 parent, songs, librarian)
                 b.set_sensitive(is_file)
             self.append(b)
 
         if edit:
+            self.separate()
             b = qltk.MenuItem(_("Edit _Tags"), Gtk.STOCK_PROPERTIES)
-            if accels is not None:
-                key, val = Gtk.accelerator_parse("<alt>Return")
-                b.add_accelerator(
-                    'activate', accels, key, val, Gtk.AccelFlags.VISIBLE)
-            b.connect_object(
-                'activate', SongProperties, librarian, songs, parent)
+            qltk.add_fake_accel(b, "<alt>Return")
+
+            def song_properties_cb(menu_item):
+                window = SongProperties(librarian, songs, parent)
+                window.show()
+
+            b.connect('activate', song_properties_cb)
             self.append(b)
 
-            b = Gtk.ImageMenuItem(Gtk.STOCK_INFO, use_stock=True)
-            if accels is not None:
-                b.add_accelerator('activate', accels, ord('I'),
-                                  Gdk.ModifierType.CONTROL_MASK,
-                                  Gtk.AccelFlags.VISIBLE)
-            b.connect_object('activate', Information, librarian, songs, parent)
+            b = Gtk.ImageMenuItem(label=Gtk.STOCK_INFO, use_stock=True)
+            qltk.add_fake_accel(b, "<ctrl>I")
+
+            def information_cb(menu_item):
+                window = Information(librarian, songs, parent)
+                window.show()
+            b.connect('activate', information_cb)
             self.append(b)
 
         self.connect_object('selection-done', Gtk.Menu.destroy, self)
@@ -313,16 +336,3 @@ class SongsMenu(Gtk.Menu):
         if songs:
             from quodlibet import app
             app.window.playlist.enqueue(songs)
-
-    def __delete(self, item, songs, library):
-        songs = set(songs)
-        files = [song["~filename"] for song in songs]
-        d = DeleteDialog(None, files)
-        removed = dict.fromkeys(d.run())
-        d.destroy()
-        removed = filter(lambda s: s["~filename"] in removed, songs)
-        if removed:
-            try:
-                library.librarian.remove(removed)
-            except AttributeError:
-                library.remove(removed)
