@@ -12,6 +12,7 @@ from quodlibet import util
 
 from quodlibet.qltk.views import HintedTreeView, TreeViewColumn
 from quodlibet.qltk.wlw import WritingWindow
+from quodlibet.util.path import fsdecode
 
 
 class TrackNumbers(Gtk.VBox):
@@ -48,7 +49,7 @@ class TrackNumbers(Gtk.VBox):
         hbox2.pack_start(preview, False, True, 0)
 
         model = Gtk.ListStore(object, str, str)
-        view = HintedTreeView(model)
+        view = HintedTreeView(model=model)
 
         self.pack_start(hbox2, False, True, 0)
 
@@ -69,7 +70,7 @@ class TrackNumbers(Gtk.VBox):
         self.pack_start(w, True, True, 0)
 
         bbox = Gtk.HButtonBox()
-        bbox.set_spacing(12)
+        bbox.set_spacing(6)
         bbox.set_layout(Gtk.ButtonBoxStyle.END)
         save = Gtk.Button(stock=Gtk.STOCK_SAVE)
         save.connect_object(
@@ -96,7 +97,8 @@ class TrackNumbers(Gtk.VBox):
             'changed', self.__class__.__update, self,
             spin_total, model, save, revert)
 
-        self.show_all()
+        for child in self.get_children():
+            child.show_all()
 
     def __row_edited(self, render, path, new, model, preview, save):
         row = model[path]
@@ -107,7 +109,7 @@ class TrackNumbers(Gtk.VBox):
 
     def __save_files(self, parent, model, library):
         win = WritingWindow(parent, len(model))
-        was_changed = []
+        was_changed = set()
         for song, track in [(r[0], r[2]) for r in model]:
             if song.get("tracknumber") == track:
                 win.step()
@@ -118,7 +120,7 @@ class TrackNumbers(Gtk.VBox):
                   "Saving without refreshing your library may "
                   "overwrite other changes to the song.\n\n"
                   "Save this song anyway?") %
-                util.escape(util.fsdecode(song("~basename")))
+                util.escape(fsdecode(song("~basename")))
                 ).run():
                 break
             song["tracknumber"] = track
@@ -131,10 +133,10 @@ class TrackNumbers(Gtk.VBox):
                     _("Saving <b>%s</b> failed. The file may be "
                       "read-only, corrupted, or you do not have "
                       "permission to edit it.") %
-                    util.escape(util.fsdecode(song('~basename')))).run()
+                    util.escape(fsdecode(song('~basename')))).run()
                 library.reload(song, changed=was_changed)
                 break
-            was_changed.append(song)
+            was_changed.add(song)
             if win.step():
                 break
         library.changed(was_changed)
@@ -168,7 +170,7 @@ class TrackNumbers(Gtk.VBox):
         else:
             self.set_sensitive(True)
         for song in songs:
-            basename = util.fsdecode(song("~basename"))
+            basename = fsdecode(song("~basename"))
             model.append(row=[song, basename, song("tracknumber")])
         save.set_sensitive(False)
         revert.set_sensitive(False)
