@@ -1,4 +1,4 @@
-# Copyright 2012 Christoph Reiter
+# Copyright 2012,2014 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -7,18 +7,20 @@
 from gi.repository import Gtk, GObject, Gdk
 
 from quodlibet import config
-from quodlibet.qltk import get_top_parent
+from quodlibet.qltk import get_top_parent, is_wayland
+from quodlibet.util import DeferredSignal
 
 
 class Window(Gtk.Window):
     """Base window class the keeps track of all window instances.
 
-    All active instances can be accessed through Window.instances.
+    All active instances can be accessed through Window.windows.
     By defining dialog=True as a kwarg binds Escape to close, otherwise
     ^W will close the window.
     """
 
-    instances = []
+    windows = []
+    _preven_inital_show = False
 
     __gsignals__ = {
         "close-accel": (GObject.SIGNAL_RUN_LAST | GObject.SIGNAL_ACTION,
@@ -28,7 +30,7 @@ class Window(Gtk.Window):
     def __init__(self, *args, **kwargs):
         dialog = kwargs.pop("dialog", True)
         super(Window, self).__init__(*args, **kwargs)
-        type(self).instances.append(self)
+        type(self).windows.append(self)
         self.__accels = Gtk.AccelGroup()
         if dialog:
             self.set_type_hint(Gdk.WindowTypeHint.DIALOG)
@@ -41,7 +43,7 @@ class Window(Gtk.Window):
         else:
             esc, mod = Gtk.accelerator_parse("Escape")
             self.add_accelerator('close-accel', self.__accels, esc, mod, 0)
-        self.connect_object('destroy', type(self).instances.remove, self)
+        self.connect_object('destroy', type(self).windows.remove, self)
 
     def set_transient_for(self, parent):
         """Set a parent for the window.
@@ -69,6 +71,18 @@ class Window(Gtk.Window):
         if not self.emit('delete-event', Gdk.Event.new(Gdk.EventType.DELETE)):
             self.destroy()
 
+    @classmethod
+    def prevent_inital_show(cls, value):
+        cls._preven_inital_show = bool(value)
+
+    def show_maybe(self):
+        """Show the window, except if prevent_inital_show() was called and
+        this is the first time
+        """
+
+        if not self._preven_inital_show:
+            self.show()
+
 
 class PersistentWindowMixin(object):
     """A mixin for saving/restoring window size/position/maximized state"""
@@ -87,19 +101,25 @@ class PersistentWindowMixin(object):
         self.__state = 0
         self.__name = config_prefix
         self.__size_suffix = size_suffix
-        self.connect('configure-event', self.__save_size)
+        self.__save_size_deferred = DeferredSignal(
+            self.__do_save_size, timeout=50, owner=self)
+        self.connect('configure-event', self.__configure_event)
         self.connect('window-state-event', self.__window_state_changed)
-        self.connect('map', self.__map)
+        self.connect('notify::visible', self.__visible_changed)
         self.__restore_window_state()
 
-    def __map(self, *args):
-        # Some WMs (metacity..) tend to forget the position randomly
-        self.__restore_window_state()
+    def __visible_changed(self, *args):
+        if not self.get_visible():
+            # https://bugzilla.gnome.org/show_bug.cgi?id=731287
+            # if we restore after hide, mutter will remember for the next show
+            # hurray!
+            self.__restore_window_state()
 
     def __restore_window_state(self):
+        if not is_wayland():
+            self.__restore_state()
+            self.__restore_position()
         self.__restore_size()
-        self.__restore_state()
-        self.__restore_position()
 
     def __conf(self, name):
         if name == "size":
@@ -127,14 +147,25 @@ class PersistentWindowMixin(object):
         screen = self.get_screen()
         x = min(x, screen.get_width())
         y = min(y, screen.get_height())
-        if x >= 0 and y >= 0:
+        if x >= 1 and y >= 1:
             self.resize(x, y)
 
-    def __save_size(self, window, event):
+    def __configure_event(self, window, event):
+        # xfwm4 resized the window before it maximizes it, which leads
+        # to QL remembering the wrong size. Work around that by waiting
+        # until configure-event settles down, at which point the maximized
+        # state should be set
+        # WARNING: we can't keep the event, because PyGObject doesn't
+        # keep it alive; so extract width/height before returning here.
+
+        self.__save_size_deferred(event.width, event.height)
+        return False
+
+    def __do_save_size(self, width, height):
         if self.__state & Gdk.WindowState.MAXIMIZED:
             return
 
-        value = "%d %d" % (event.width, event.height)
+        value = "%d %d" % (width, height)
         config.set("memory", self.__conf("size"), value)
         if self.get_property("visible"):
             pos_value = '%s %s' % self.get_position()
