@@ -11,7 +11,7 @@ from gi.repository import Gtk, GObject, GLib, Gio
 
 from quodlibet import util
 from quodlibet import config
-from quodlibet.qltk import is_accel
+from quodlibet.qltk import is_accel, add_css
 from quodlibet.qltk.window import Window, UniqueWindow
 
 
@@ -164,7 +164,7 @@ class Notebook(Gtk.Notebook):
                 raise TypeError("no page.title and no label given")
 
         if not isinstance(label, Gtk.Widget):
-            label = Gtk.Label(label)
+            label = Gtk.Label(label=label)
         super(Notebook, self).append_page(page, label)
 
 
@@ -310,6 +310,20 @@ class ConfigRVPaned(ConfigRPaned):
     ORIENTATION = Gtk.Orientation.VERTICAL
 
 
+class SmallImageButton(Gtk.Button):
+    """A button for images with less padding"""
+
+    def __init__(self, **kwargs):
+        super(SmallImageButton, self).__init__(**kwargs)
+
+        self.set_size_request(26, 26)
+        add_css(self, """
+            * {
+                padding: 0px;
+            }
+        """)
+
+
 def ClearButton(entry=None):
     clear = Gtk.Button()
     clear.add(Gtk.Image.new_from_stock(Gtk.STOCK_CLEAR, Gtk.IconSize.MENU))
