@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright 2004-2009 Joe Wreschnig, Michael Urman, Steven Robertson
-#           2011,2012 Nick Boultbee
+#           2011,2013 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -9,64 +9,31 @@
 import os
 import random
 import re
+import ctypes
+import ctypes.util
 import sys
 import traceback
 import urlparse
 import unicodedata
-import urllib
-import tempfile
 import subprocess
 import webbrowser
+import contextlib
 
-# title function was moved to a separate module
+# Windows doesn't have fcntl, just don't lock for now
+try:
+    import fcntl
+    fcntl
+except ImportError:
+    fcntl = None
+
+from quodlibet.util.path import (fsdecode, iscommand, fsnative,
+    expanduser, pathname2url, is_fsnative)
+from quodlibet.util.string.splitters import split_value
 from quodlibet.util.titlecase import title
 
 from quodlibet.const import FSCODING as fscoding, SUPPORT_EMAIL, COPYRIGHT
 from quodlibet.util.dprint import print_d, print_
 
-if os.name == "nt":
-    from win32com.shell import shellcon, shell
-
-
-def strip_win32_incompat(string, BAD='\:*?;"<>|'):
-    """Strip Win32-incompatible characters.
-
-    This only works correctly on Unicode strings.
-    """
-    new = u"".join(map(lambda s: (s in BAD and "_") or s, string))
-    parts = new.split(os.sep)
-
-    def fix_end(string):
-        return re.sub(r'[\. ]$', "_", string)
-    return unicode(os.sep).join(map(fix_end, parts))
-
-
-def strip_win32_incompat_from_path(string):
-    """Strip Win32-incompatible chars from a path, ignoring os.sep
-    and the drive part"""
-    drive, tail = os.path.splitdrive(string)
-    tail = os.sep.join(map(strip_win32_incompat, tail.split(os.sep)))
-    return drive + tail
-
-
-def listdir(path, hidden=False):
-    """List files in a directory, sorted, fully-qualified.
-
-    If hidden is false, Unix-style hidden files are not returned.
-    """
-    path = fsnative(path)
-    if hidden:
-        filt = None
-    else:
-        filt = lambda base: not base.startswith(".")
-    if path.endswith(os.sep):
-        join = "".join
-    else:
-        join = os.sep.join
-    return [join([path, basename])
-            for basename in sorted(os.listdir(path))
-            if filt(basename)]
-
 
 class InstanceTracker(object):
     """A mixin for GObjects to return a list of all alive objects
@@ -219,30 +186,6 @@ class OptionParser(object):
             return transopts, args
 
 
-def mtime(filename):
-    """Return the mtime of a file, or 0 if an error occurs."""
-    try:
-        return os.path.getmtime(filename)
-    except OSError:
-        return 0
-
-
-def size(filename):
-    """Return the size of a file, or 0 if an error occurs."""
-    try:
-        return os.path.getsize(filename)
-    except OSError:
-        return 0
-
-
-def mkdir(dir, *args):
-    """Make a directory, including all its parent directories. This does not
-    raise an exception if the directory already exists (and is a
-    directory)."""
-    if not os.path.isdir(dir):
-        os.makedirs(dir, *args)
-
-
 def escape(str):
     """Escape a string in a manner suitable for XML/Pango."""
     return str.replace("&", "&amp;").replace("<", "&lt;").replace(">", "&gt;")
@@ -253,20 +196,6 @@ def unescape(str):
     return str.replace("&lt;", "<").replace("&gt;", ">").replace("&amp;", "&")
 
 
-def escape_filename(s):
-    """Escape a string in a manner suitable for a filename."""
-    if isinstance(s, unicode):
-        s = s.encode("utf-8")
-    return urllib.quote(s, safe="").decode("utf-8")
-
-
-def unescape_filename(s):
-    """Unescape a string in a manner suitable for a filename."""
-    if isinstance(s, unicode):
-        s = s.encode("utf-8")
-    return urllib.unquote(s).decode("utf-8")
-
-
 def parse_time(timestr, err=(ValueError, re.error)):
     """Parse a time string in hh:mm:ss, mm:ss, or ss format."""
     if timestr[0:1] == "-":
@@ -280,18 +209,18 @@ def parse_time(timestr, err=(ValueError, re.error)):
     except err:
         return 0
 
-RATING_PRECISION = 0.25
-RATING_SYMBOL = u'\u2605'
-BLANK_RATING_SYMBOL = u'\u2606'
-
 
 def format_rating(value, blank=True):
     """Turn a number into a sequence of rating symbols."""
-    steps = int(1 / RATING_PRECISION)
+
+    from quodlibet import config
+
+    prefs = config.RATINGS
+    steps = prefs.number
     value = max(min(value, 1.0), 0)
     ons = int(round(steps * value))
     offs = (steps - ons) if blank else 0
-    return RATING_SYMBOL * ons + BLANK_RATING_SYMBOL * offs
+    return prefs.full_symbol * ons + prefs.blank_symbol * offs
 
 
 def format_size(size):
@@ -329,10 +258,16 @@ def format_time(time):
         return "%s%d:%02d" % (prefix, time // 60, time % 60)
 
 
-def format_time_long(time):
-    """Turn a time value in seconds into x hours, x minutes, etc."""
+def format_time_long(time, limit=2):
+    """Turn a time value in seconds into x hours, x minutes, etc.
+
+    `limit` limits the count of units used, so the result will be <= time.
+    0 means no limit.
+    """
+
     if time < 1:
         return _("No time information")
+
     cutoffs = [
         (60, "%d seconds", "%d second"),
         (60, "%d minutes", "%d minute"),
@@ -340,6 +275,7 @@ def format_time_long(time):
         (365, "%d days", "%d day"),
         (None, "%d years", "%d year"),
     ]
+
     time_str = []
     for divisor, plural, single in cutoffs:
         if time < 1:
@@ -351,180 +287,21 @@ def format_time_long(time):
         if unit:
             time_str.append(ngettext(single, plural, unit) % unit)
     time_str.reverse()
-    if len(time_str) > 2:
-        time_str.pop()
+
+    if limit:
+        time_str = time_str[:limit]
+
     return ", ".join(time_str)
 
 
-def fsdecode(s, note=True):
-    """Decoding a string according to the filesystem encoding.
-    note specifies whether a note should be appended if decoding failed."""
-    if isinstance(s, unicode):
-        return s
-    elif note:
-        return decode(s, fscoding)
-    else:
-        return s.decode(fscoding, 'replace')
-
-
-def fsencode(s, note=False):
-    """Encode a string according to the filesystem encoding.
-    note specifies whether a note should be appended if encoding failed."""
-    if isinstance(s, str):
-        return s
-    elif note:
-        return encode(s, fscoding)
-    else:
-        return s.encode(fscoding, 'replace')
-
-"""
-Path related functions like open, os.listdir have different behavior on win32
-
-- Passing a string calls the old non unicode win API.
-  In case of listdir this leads to "?" for >1byte chars and to
-  1 byte chars encoded using the fs encoding. -> DO NOT USE!
-
-- Passing a unicode object internally calls the windows unicode functions.
-  This will mostly lead to proper unicode paths (except expanduser).
-
-  And that's why QL is using unicode paths on win and encoded paths
-  everywhere else.
-"""
-
-if sys.platform == "win32":
-    fsnative = fsdecode  # Decode a filename on windows
-else:
-    fsnative = fsencode  # Encode it on other platforms
-
-
-def split_scan_dirs(s):
-    """Split the value of the "scan" setting, accounting for drive letters on
-    win32."""
-    if sys.platform == "win32":
-        return filter(None, re.findall(r"[a-zA-Z]:[\\/][^:]*", s))
-    else:
-        return filter(None, s.split(":"))
-
-
-def decode(s, charset="utf-8"):
-    """Decode a string; if an error occurs, replace characters and append
-    a note to the string."""
-    try:
-        return s.decode(charset)
-    except UnicodeError:
-        return s.decode(charset, "replace") + " " + _("[Invalid Encoding]")
-
-
-def encode(s, charset="utf-8"):
-    """Encode a string; if an error occurs, replace characters and append
-    a note to the string."""
-    try:
-        return s.encode(charset)
-    except UnicodeError:
-        return (s + " " + _("[Invalid Encoding]")).encode(charset, "replace")
-
-
-def iscommand(s):
-    """True if an executable file 's' exists in the user's path, or is a
-    fully-qualified existing executable file."""
-
-    if s == "" or os.path.sep in s:
-        return os.path.isfile(s) and os.access(s, os.X_OK)
-    else:
-        s = s.split()[0]
-        for p in os.defpath.split(os.path.pathsep):
-            p2 = os.path.join(p, s)
-            if os.path.isfile(p2) and os.access(p2, os.X_OK):
-                return True
-        else:
-            return False
-
-
 def capitalize(str):
     """Capitalize a string, not affecting any character after the first."""
     return str[:1].upper() + str[1:]
 
 
-def split_value(s, splitters=["/", "&", ","]):
-    """Splits a string. The first match in 'splitters' is used as the
-    separator; subsequent matches are intentionally ignored."""
-    if not splitters:
-        return [s.strip()]
-    values = s.split("\n")
-    for spl in splitters:
-        spl = re.compile(r"\b\s*%s\s*\b" % re.escape(spl), re.UNICODE)
-        if not filter(spl.search, values):
-            continue
-        new_values = []
-        for v in values:
-            new_values.extend([st.strip() for st in spl.split(v)])
-        return new_values
-    return values
-
-
-def split_title(s, splitters=["/", "&", ","]):
-    title, subtitle = find_subtitle(s)
-    return ((title.strip(), split_value(subtitle, splitters))
-            if subtitle else (s, []))
-
-
-__FEATURING = ["feat.", "featuring", "feat", "ft", "ft.", "with", "w/"]
-__ORIGINALLY = ["originally by ", " cover"]
-# Cache case-insensitive regex searches of the above
-__FEAT_REGEX = [re.compile(re.escape(s + " "), re.I) for s in __FEATURING]
-__ORIG_REGEX = [re.compile(re.escape(s), re.I) for s in __ORIGINALLY]
-
-
-def split_people(s, splitters=["/", "&", ","]):
-    title, subtitle = find_subtitle(s)
-    if not subtitle:
-        parts = s.split(" ")
-        if len(parts) > 2:
-            for feat in __FEATURING:
-                try:
-                    i = [p.lower() for p in parts].index(feat)
-                    orig = " ".join(parts[:i])
-                    others = " ".join(parts[i + 1:])
-                    return (orig, split_value(others, splitters))
-                except (ValueError, IndexError):
-                    pass
-        return (s, [])
-    else:
-        old = subtitle
-        # TODO: allow multiple substitutions across types, maybe
-        for regex in (__FEAT_REGEX + __ORIG_REGEX):
-            subtitle = re.sub(regex, "", subtitle, 1)
-            if old != subtitle:
-                # Only change once
-                break
-        values = split_value(subtitle, splitters)
-        return (title.strip(), values)
-
-
-def split_album(s):
-    name, disc = find_subtitle(s)
-    if not disc:
-        parts = s.split(" ")
-        if len(parts) > 2:
-            lower = parts[-2].lower()
-            if "disc" in lower or "disk" in lower:
-                return (" ".join(parts[:-2]), parts[-1])
-        return (s, None)
-    else:
-        parts = disc.split()
-        if (len(parts) == 2 and
-                parts[0].lower() in ["disc", "disk", "cd", "vol", "vol."]):
-            try:
-                return (name, parts[1])
-            except:
-                return (s, None)
-        else:
-            return (s, None)
-
-
-def split_numeric(s, limit=10,
-                  reg=re.compile(r"[0-9][0-9]*\.?[0-9]*").search,
-                  join=u" ".join):
+def _split_numeric_sortkey(s, limit=10,
+                           reg=re.compile(r"[0-9][0-9]*\.?[0-9]*").search,
+                           join=u" ".join):
     """Separate numeric values from the string and convert to float, so
     it can be used for human sorting. Also removes all extra whitespace."""
     result = reg(s)
@@ -535,52 +312,14 @@ def split_numeric(s, limit=10,
         return (
             join(s[:start].split()),
             float(result.group()),
-            split_numeric(s[end:], limit - 1))
+            _split_numeric_sortkey(s[end:], limit - 1))
 
 
 def human_sort_key(s, normalize=unicodedata.normalize):
     if not isinstance(s, unicode):
         s = s.decode("utf-8")
     s = normalize("NFD", s.lower())
-    return s and split_numeric(s)
-
-
-def find_subtitle(title):
-    if isinstance(title, str):
-        title = title.decode('utf-8', 'replace')
-    for pair in [u"[]", u"()", u"~~", u"--", u"\u301c\u301c", u'\uff08\uff09']:
-        if pair[0] in title[:-1] and title.endswith(pair[1]):
-            r = len(pair[1])
-            l = title[0:-r].rindex(pair[0])
-            if l != 0:
-                subtitle = title[l + len(pair[0]):-r]
-                title = title[:l]
-                return title.rstrip(), subtitle
-    else:
-        return title, None
-
-
-def expanduser(filename):
-    """needed because expanduser does not return wide character paths
-    on windows even if a unicode path gets passed."""
-    if os.name == "nt":
-        profile = shell.SHGetFolderPath(0, shellcon.CSIDL_PROFILE, 0, 0)
-        if filename == "~":
-            return profile
-        if filename.startswith(u"~" + os.path.sep):
-            return os.path.join(profile, filename[2:])
-    return os.path.expanduser(filename)
-
-
-def unexpand(filename, HOME=expanduser("~")):
-    """Replace the user's home directory with ~/, if it appears at the
-    start of the path name."""
-    sub = (os.name == "nt" and "%USERPROFILE%") or "~"
-    if filename == HOME:
-        return sub
-    elif filename.startswith(HOME + os.path.sep):
-        filename = filename.replace(HOME, sub, 1)
-    return filename
+    return s and _split_numeric_sortkey(s)
 
 
 def website(site):
@@ -743,28 +482,60 @@ class DeferredSignal(object):
     priority and prevents multiple calls from being inserted in the
     mainloop at a time, greatly improving responsiveness in some places.
 
+    When the target function will finally be called the arguments passed
+    are the last arguments passed to DeferredSignal.
+
+    If `owner` is given, it will not call the target after the owner is
+    destroyed.
+
     Example usage:
 
     def func(widget, user_arg):
         pass
-    widget.connect('signal', DeferredSignal(func), user_arg)
+    widget.connect('signal', DeferredSignal(func, owner=widget), user_arg)
     """
 
-    __slots__ = ['func', 'dirty']
+    def __init__(self, func, timeout=None, owner=None):
+        """timeout in milliseconds"""
 
-    def __init__(self, func):
         self.func = func
         self.dirty = False
+        self.args = None
+
+        if owner:
+            def destroy_cb(owner):
+                self.abort()
+            owner.connect("destroy", destroy_cb)
+
+        from gi.repository import GLib
+        if timeout is None:
+            self.do_idle_add = GLib.idle_add
+        else:
+            self.do_idle_add = lambda f: GLib.timeout_add(timeout, f)
+
+    def abort(self):
+        """Abort any queued up calls.
+
+        Can still be reused afterwards.
+        """
+
+        if self.dirty:
+            from gi.repository import GLib
+            GLib.source_remove(self._id)
+            self.dirty = False
+            self.args = None
 
     def __call__(self, *args):
+        self.args = args
         if not self.dirty:
             self.dirty = True
-            from gi.repository import GLib
-            GLib.idle_add(self._wrap, *args)
+            self._id = self.do_idle_add(self._wrap)
 
-    def _wrap(self, *args):
-        self.func(*args)
+    def _wrap(self):
+        self.func(*self.args)
         self.dirty = False
+        self.args = None
+        return False
 
 
 def gobject_weak(fun, *args, **kwargs):
@@ -800,69 +571,6 @@ class cached_property(object):
         return result
 
 
-def xdg_get_system_data_dirs():
-    """http://standards.freedesktop.org/basedir-spec/latest/"""
-    data_dirs = os.getenv("XDG_DATA_DIRS")
-    if data_dirs:
-        return map(os.path.abspath, data_dirs.split(":"))
-    else:
-        return ("/usr/local/share/", "/usr/share/")
-
-
-def xdg_get_cache_home():
-    data_home = os.getenv("XDG_CACHE_HOME")
-    if data_home:
-        return os.path.abspath(data_home)
-    else:
-        return os.path.join(os.path.expanduser("~"), ".cache")
-
-
-def xdg_get_data_home():
-    data_home = os.getenv("XDG_DATA_HOME")
-    if data_home:
-        return os.path.abspath(data_home)
-    else:
-        return os.path.join(os.path.expanduser("~"), ".local", "share")
-
-
-def find_mount_point(path):
-    while not os.path.ismount(path):
-        path = os.path.dirname(path)
-    return path
-
-
-def pathname2url_win32(path):
-    # stdlib version raises IOError for more than one ':' which can appear
-    # using a virtual box shared folder and it inserts /// at the beginning
-    # but it should be /.
-    quote = urllib.quote
-    if path[1:2] != ":" or path[:1] == "\\":
-        if path[:2] == "\\\\":
-            path = path[2:]
-        return quote("/".join(path.split("\\")))
-    drive, remain = path.split(":", 1)
-    return "/%s:%s" % (quote(drive), quote("/".join(remain.split("\\"))))
-
-if os.name == "nt":
-    pathname2url = pathname2url_win32
-else:
-    pathname2url = urllib.pathname2url
-
-
-# See http://stackoverflow.com/questions/1151658/python-hashable-dicts
-class HashableDict(dict):
-    """Standard dict, made hashable. Useful for making sets of dicts etc"""
-
-    def __key(self):
-        return tuple((k, self[k]) for k in sorted(self))
-
-    def __hash__(self):
-        return hash(self.__key())
-
-    def __eq__(self, other):
-        return self.__key() == other.__key()
-
-
 def sanitize_tags(tags, stream=False):
     """Returns a new sanitized tag dict. stream defines if the
     tags of a main/base song should be changed or of a stream song.
@@ -999,13 +707,96 @@ def limit_songs(songs, max, weight_by_ratings=False):
         return songs[:max]
 
 
-def get_temp_cover_file(data):
-    try:
-        fn = tempfile.NamedTemporaryFile()
-        fn.write(data)
-        fn.flush()
-        fn.seek(0, 0)
-    except EnvironmentError:
-        return
+def gi_require_versions(name, versions):
+    """Like gi.require_version, but will take a list of versions.
+
+    Returns the required version or raises ValueError.
+    """
+
+    assert versions
+
+    import gi
+
+    for version in versions:
+        try:
+            gi.require_version(name, version)
+        except ValueError as e:
+            pass
+        else:
+            return version
     else:
-        return fn
+        raise e
+
+
+@contextlib.contextmanager
+def atomic_save(filename, suffix, mode):
+    """Try to replace the content of a file in the safest way possible.
+
+    * filename+suffix will be created during the process.
+    * On UNIX this operation is atomic, on Windows it is not.
+
+    with atomic_save("config.cfg", ".tmp", "wb") as f:
+        f.write(data)
+
+    Can raise.
+    """
+
+    assert is_fsnative(filename)
+
+    temp_filename = filename + suffix
+    fileobj = open(temp_filename, "wb")
+    try:
+        if fcntl is not None:
+            fcntl.flock(fileobj.fileno(), fcntl.LOCK_EX)
+
+        yield fileobj
+
+        fileobj.flush()
+        os.fsync(fileobj.fileno())
+
+        # No atomic rename on windows
+        if os.name == "nt":
+            fileobj.close()
+            try:
+                os.remove(filename)
+            except EnvironmentError:
+                pass
+
+        os.rename(temp_filename, filename)
+    finally:
+        if fcntl is not None:
+            fcntl.flock(fileobj.fileno(), fcntl.LOCK_UN)
+        fileobj.close()
+
+
+def load_library(names, shared=True):
+    """Load a ctypes library with a range of names to try.
+
+    Handles direct .so names and library names ["libgpod.so", "gpod"].
+
+    If shared is True can return a shared instance.
+    Raises OSError if not found.
+
+    Returns (library, name)
+    """
+
+    if not names:
+        raise ValueError
+
+    if shared:
+        load_func = lambda n: getattr(ctypes.cdll, n)
+    else:
+        load_func = ctypes.cdll.LoadLibrary
+
+    errors = []
+    for name in names:
+        dlopen_name = name
+        if ".so" not in name and ".dll" not in name:
+            dlopen_name = ctypes.util.find_library(name) or name
+
+        try:
+            return load_func(dlopen_name), name
+        except OSError as e:
+            errors.append(str(e))
+
+    raise OSError("\n".join(errors))
