@@ -6,6 +6,8 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 
+from __future__ import absolute_import
+
 from gi.repository import GLib
 
 import os
@@ -13,10 +15,12 @@ import random
 
 from quodlibet import util
 from quodlibet import config
-from quodlibet import const
 from quodlibet.formats._audio import PEOPLE, TAG_TO_SORT, INTERN_NUM_DEFAULT
 from quodlibet.util import thumbnails
-from collections import Iterable, MutableSequence, defaultdict
+from collections import Iterable
+from quodlibet.util.path import escape_filename, unescape_filename
+from quodlibet.util.path import bytes2fsnative, is_fsnative, fsnative2bytes
+from .collections import HashedList
 
 
 ELPOEP = list(reversed(PEOPLE))
@@ -31,7 +35,7 @@ def avg(nums):
 def bayesian_average(nums, c=None, m=None):
     """Returns the Bayesian average of an iterable of numbers,
     with parameters defaulting to config specific to ~#rating."""
-    m = m or const.DEFAULT_RATING
+    m = m or config.RATINGS.default
     c = c or config.getfloat("settings", "bayesian_rating_factor", 0.0)
     ret = float(m * c + sum(nums)) / (c + len(nums))
     return ret
@@ -111,7 +115,7 @@ class Collection(object):
 
     def comma(self, key):
         value = self.get(key)
-        return (value if isinstance(value, (int, float))
+        return (value if isinstance(value, (int, float, long))
                 else value.replace("\n", ", "))
 
     def list(self, key):
@@ -162,7 +166,8 @@ class Collection(object):
                 w = lambda s: s("~#bitrate", 0) * s("~#length", 0)
                 return sum(w(song) for song in self.songs) / length
             else:
-                # Unknown key. AudioFile will try to cast the values to int,
+                # Standard or unknown numeric key.
+                # AudioFile will try to cast the values to int,
                 # default to avg
                 func = NUM_DEFAULT_FUNCS.get(key, "avg")
 
@@ -179,6 +184,7 @@ class Collection(object):
             return None
         elif key[:1] == "~":
             key = key[1:]
+            numkey = key.split(":")[0]
             keys = {"people": {}, "peoplesort": {}}
             if key in keys:
                 people = keys["people"]
@@ -215,35 +221,33 @@ class Collection(object):
                     self.__used.append(other)
                     self.__cache[other] = "\n".join(values)
                 return ret
-            elif key == "length":
-                length = self.__get_value("~#length")
+            elif numkey == "length":
+                length = self.__get_value("~#" + key)
                 return None if length is None else util.format_time(length)
-            elif key == "long-length":
-                length = self.__get_value("~#length")
-                if length is None:
-                    return None
-                else:
-                    return util.format_time_long(length)
-            elif key == "tracks":
-                tracks = self.__get_value("~#tracks")
+            elif numkey == "long-length":
+                length = self.__get_value("~#" + key[5:])
+                return (None if length is None
+                        else util.format_time_long(length))
+            elif numkey == "tracks":
+                tracks = self.__get_value("~#" + key)
                 return (None if tracks is None else
                         ngettext("%d track", "%d tracks", tracks) % tracks)
-            elif key == "discs":
-                discs = self.__get_value("~#discs")
+            elif numkey == "discs":
+                discs = self.__get_value("~#" + key)
                 if discs > 1:
                     return ngettext("%d disc", "%d discs", discs) % discs
                 else:
                     # TODO: check this is correct for discs == 1
                     return None
-            elif key == "rating":
-                rating = self.__get_value("~#rating")
+            elif numkey == "rating":
+                rating = self.__get_value("~#" + key)
                 if rating is None:
                     return None
                 return util.format_rating(rating)
             elif key == "cover":
                 return ((self.cover != type(self).cover) and "y") or None
-            elif key == "filesize":
-                size = self.__get_value("~#filesize")
+            elif numkey == "filesize":
+                size = self.__get_value("~#" + key)
                 return None if size is None else util.format_size(size)
             key = "~" + key
 
@@ -263,7 +267,7 @@ class Album(Collection):
     """Like a `Collection` but adds cover scanning, some attributes for sorting
     and uses a set for the songs."""
 
-    COVER_SIZE = 48
+    COVER_SIZE = 50
 
     cover = None
     scanned = False
@@ -286,13 +290,17 @@ class Album(Collection):
         self.sort = util.human_sort_key(song("albumsort"))
         self.key = song.album_key
 
+    @property
+    def str_key(self):
+        return str(self.key)
+
     def finalize(self):
         """Finalize this album. Call after songs get added or removed"""
         super(Album, self).finalize()
         self.__dict__.pop("peoplesort", None)
         self.__dict__.pop("genre", None)
 
-    def scan_cover(self, force=False):
+    def scan_cover(self, force=False, scale_factor=1):
         if (self.scanned and not force) or not self.songs:
             return
         self.scanned = True
@@ -301,11 +309,13 @@ class Album(Collection):
         cover = song.find_cover()
 
         if cover is not None:
-            s = self.COVER_SIZE
+            s = self.COVER_SIZE * scale_factor - scale_factor * 2
+
             try:
                 round = config.getboolean("albumart", "round")
                 self.cover = thumbnails.get_thumbnail(cover.name, (s, s))
-                self.cover = thumbnails.add_border(self.cover, 30, round)
+                self.cover = thumbnails.add_border(
+                    self.cover, 30, round=round, width=scale_factor)
             except GLib.GError:
                 return
 
@@ -313,77 +323,6 @@ class Album(Collection):
         return "Album(%s)" % repr(self.key)
 
 
-class HashedList(MutableSequence):
-    """A list-like collection that can only take hashable items
-    and provides fast membership tests.
-
-    Can handle duplicate entries.
-    """
-
-    def __init__(self, arg=None):
-        self._map = defaultdict(int)
-        if arg is None:
-            self._data = []
-            return
-
-        self._data = list(arg)
-        for item in arg:
-            self._map[item] += 1
-
-    def __setitem__(self, index, item):
-        old_items = self._data[index]
-        if not isinstance(index, slice):
-            old_items = [old_items]
-
-        for old in old_items:
-            self._map[old] -= 1
-            if not self._map[old]:
-                del self._map[old]
-
-        self._data[index] = item
-
-        items = item
-        if not isinstance(index, slice):
-            items = [items]
-
-        for item in items:
-            self._map[item] += 1
-
-    def __getitem__(self, index):
-        return self._data[index]
-
-    def __delitem__(self, index):
-        items = self._data[index]
-        if not isinstance(index, slice):
-            items = [items]
-        for item in items:
-            self._map[item] -= 1
-            if not self._map[item]:
-                del self._map[item]
-        del self._data[index]
-
-    def __len__(self):
-        return len(self._data)
-
-    def insert(self, index, item):
-        self._data.insert(index, item)
-        self._map[item] += 1
-
-    def __contains__(self, item):
-        return item in self._map
-
-    def __iter__(self):
-        for item in self._data:
-            yield item
-
-    def has_duplicates(self):
-        """Returns True if any item is contained more then once"""
-        return len(self._map) != len(self)
-
-    def __repr__(self):
-        return repr(self._data)
-
-
 class Playlist(Collection, Iterable):
     """A Playlist is a `Collection` that has list-like features
     Songs can appear more than once.
@@ -393,14 +332,17 @@ class Playlist(Collection, Iterable):
 
     __instances = []
 
-    quote = staticmethod(util.escape_filename)
-    unquote = staticmethod(util.unescape_filename)
+    quote = staticmethod(escape_filename)
+    unquote = staticmethod(unescape_filename)
 
     @classmethod
-    def new(cls, dir, base=_("New Playlist"), library={}):
-        if not (dir and os.path.realpath(dir)):
-            raise ValueError("Invalid playlist directory '%s'" % (dir,))
-        p = Playlist(dir, "", library=library)
+    def new(cls, dir_, base=_("New Playlist"), library=None):
+        assert is_fsnative(dir_)
+
+        if not (dir_ and os.path.realpath(dir_)):
+            raise ValueError("Invalid playlist directory %r" % (dir_,))
+
+        p = Playlist(dir_, "", library)
         i = 0
         try:
             p.rename(base)
@@ -414,7 +356,9 @@ class Playlist(Collection, Iterable):
         return p
 
     @classmethod
-    def fromsongs(cls, dir, songs, library={}):
+    def fromsongs(cls, dir_, songs, library=None):
+        assert is_fsnative(dir_)
+
         if len(songs) == 1:
             title = songs[0].comma("title")
         else:
@@ -424,13 +368,15 @@ class Playlist(Collection, Iterable):
                 len(songs) - 1) % (
                     {'title': songs[0].comma("title"),
                      'count': len(songs) - 1})
-        playlist = cls.new(dir, title, library=library)
+
+        playlist = cls.new(dir_, title, library)
         playlist.extend(songs)
         return playlist
 
     @classmethod
     def playlists_featuring(cls, song):
         """Returns the list of playlists in which this song appears"""
+
         playlists = []
         for instance in cls.__instances:
             if song in instance._list:
@@ -440,12 +386,16 @@ class Playlist(Collection, Iterable):
     # List-like methods, for compatibilty with original Playlist class.
     def extend(self, songs):
         self._list.extend(songs)
+        self.finalize()
 
     def append(self, song):
-        return self._list.append(song)
+        ret = self._list.append(song)
+        self.finalize()
+        return ret
 
     def clear(self):
         del self._list[:]
+        self.finalize()
 
     def __iter__(self):
         return iter(self._list)
@@ -461,6 +411,7 @@ class Playlist(Collection, Iterable):
 
     def __setitem__(self, key, value):
         self._list[key] = value
+        self.finalize()
 
     @property
     def songs(self):
@@ -475,19 +426,30 @@ class Playlist(Collection, Iterable):
 
         self.name = name
         self.dir = dir
+        self.library = library
         self._list = HashedList()
-        basename = self.quote(name)
         try:
-            for line in file(os.path.join(self.dir, basename), "r"):
-                line = util.fsnative(line.rstrip())
-                if line in library:
-                    self._list.append(library[line])
-                elif library and library.masked(line):
-                    self._list.append(line)
+            with open(self.filename, "rb") as h:
+                for line in h:
+                    assert library is not None
+                    try:
+                        line = bytes2fsnative(line.rstrip())
+                    except ValueError:
+                        # decoding failed
+                        continue
+                    if line in library:
+                        self._list.append(library[line])
+                    elif library and library.masked(line):
+                        self._list.append(line)
         except IOError:
             if self.name:
                 self.write()
 
+    @property
+    def filename(self):
+        basename = self.quote(self.name)
+        return os.path.join(self.dir, basename)
+
     def rename(self, newname):
         if isinstance(newname, unicode):
             newname = newname.encode('utf-8')
@@ -499,7 +461,7 @@ class Playlist(Collection, Iterable):
                 _("A playlist named %s already exists.") % newname)
         else:
             try:
-                os.unlink(os.path.join(self.dir, self.quote(self.name)))
+                os.unlink(self.filename)
             except EnvironmentError:
                 pass
             self.name = newname
@@ -513,14 +475,14 @@ class Playlist(Collection, Iterable):
                 changed = True
         return changed
 
-    def remove_songs(self, songs, library, leave_dupes=False):
+    def remove_songs(self, songs, leave_dupes=False):
         """Removes `songs` from this playlist if they are there,
          removing only the first reference if `leave_dupes` is True
         """
         changed = False
         for song in songs:
             # TODO: document the "library.masked" business
-            if library.masked(song):
+            if self.library is not None and self.library.masked(song):
                 while True:
                     try:
                         self._list[self.index(song)] = song("~filename")
@@ -536,6 +498,8 @@ class Playlist(Collection, Iterable):
                         break
                 else:
                     changed = True
+        if changed:
+            self.finalize()
         return changed
 
     def has_songs(self, songs):
@@ -552,20 +516,19 @@ class Playlist(Collection, Iterable):
     def delete(self):
         self.clear()
         try:
-            os.unlink(os.path.join(self.dir, self.quote(self.name)))
+            os.unlink(self.filename)
         except EnvironmentError:
             pass
         if self in self.__instances:
             self.__instances.remove(self)
 
     def write(self):
-        basename = self.quote(self.name)
-        with open(os.path.join(self.dir, basename), "w") as f:
+        with open(self.filename, "wb") as f:
             for song in self._list:
-                try:
-                    f.write(util.fsencode(song("~filename")) + "\n")
-                except TypeError:
-                    f.write(song + "\n")
+                if isinstance(song, basestring):
+                    f.write(fsnative2bytes(song) + "\n")
+                else:
+                    f.write(fsnative2bytes(song("~filename")) + "\n")
 
     def format(self):
         """Return a markup representation of information for this playlist"""
@@ -580,6 +543,7 @@ class Playlist(Collection, Iterable):
                " / %s" %
                util.format_size(total_size) if total_size > 0 else "")
 
+    @property
     def has_duplicates(self):
         """Returns True if there are any duplicated files in this playlist"""
         return self._list.has_duplicates()
