@@ -8,7 +8,7 @@ import unittest
 import tempfile
 import shutil
 from quodlibet.util.dprint import Colorise, print_
-from quodlibet.util.path import fsnative
+from quodlibet.util.path import fsnative, is_fsnative
 
 from unittest import TestCase as OrigTestCase
 
@@ -31,23 +31,26 @@ class AbstractTestCase(TestCase):
 
 skipped = []
 skipped_reason = {}
+skipped_warn = set()
 
 
-def skip(cls, reason=None):
+def skip(cls, reason=None, warn=True):
     assert inspect.isclass(cls)
 
     skipped.append(cls)
     if reason:
         skipped_reason[cls] = reason
+    if warn:
+        skipped_warn.add(cls)
 
     return cls
 
 
-def skipUnless(value, reason=None):
+def skipUnless(value, *args, **kwargs):
     def dec(cls):
         if value:
             return cls
-        return skip(cls, reason=reason)
+        return skip(cls, *args, **kwargs)
     return dec
 
 
@@ -62,6 +65,7 @@ _TEMP_DIR = None
 def _wrap_tempfile(func):
     def wrap(*args, **kwargs):
         if kwargs.get("dir") is None:
+            assert is_fsnative(_TEMP_DIR)
             kwargs["dir"] = _TEMP_DIR
         return func(*args, **kwargs)
     return wrap
@@ -71,12 +75,15 @@ NamedTemporaryFile = _wrap_tempfile(tempfile.NamedTemporaryFile)
 
 
 def mkdtemp(*args, **kwargs):
-    return fsnative(_wrap_tempfile(tempfile.mkdtemp)(*args, **kwargs))
+    path = _wrap_tempfile(tempfile.mkdtemp)(*args, **kwargs)
+    assert is_fsnative(path)
+    return path
 
 
 def mkstemp(*args, **kwargs):
     fd, filename = _wrap_tempfile(tempfile.mkstemp)(*args, **kwargs)
-    return (fd, fsnative(filename))
+    assert is_fsnative(filename)
+    return (fd, filename)
 
 
 class Result(unittest.TestResult):
@@ -95,7 +102,7 @@ class Result(unittest.TestResult):
             out.flush()
         pref = '%s (%d): ' % (Colorise.bold(test_name), num_tests)
         line = pref + " " * (self.TEST_NAME_WIDTH - len(test_name)
-                             - 6 - int(num_tests and log(num_tests, 10) or 0))
+                             - 7 - int(num_tests and log(num_tests, 10) or 0))
         print_(line, end="")
 
     def addSuccess(self, test):
@@ -152,8 +159,8 @@ def unit(run=[], filter_func=None, main=False, subdirs=None, strict=False,
             del(sys.modules[key])
 
     # create a user dir in /tmp
-    _TEMP_DIR = tempfile.mkdtemp(prefix="QL-TEST-")
-    user_dir = tempfile.mkdtemp(prefix="QL-USER-", dir=_TEMP_DIR)
+    _TEMP_DIR = tempfile.mkdtemp(prefix=fsnative(u"QL-TEST-"))
+    user_dir = tempfile.mkdtemp(prefix=fsnative(u"QL-USER-"), dir=_TEMP_DIR)
     os.environ['QUODLIBET_USERDIR'] = user_dir
 
     path = os.path.dirname(__file__)
@@ -217,7 +224,8 @@ def unit(run=[], filter_func=None, main=False, subdirs=None, strict=False,
             continue
         name = "%s.%s" % (case.__module__, case.__name__)
         reason = skipped_reason.get(case, "??")
-        print_w("Skipped test: %s (%s)" % (name, reason))
+        if case in skipped_warn:
+            print_w("Skipped test: %s (%s)" % (name, reason))
 
     import quodlibet.config
 
