@@ -8,7 +8,6 @@ from gi.repository import Gtk
 
 import dbus
 
-from tests import add
 from tests.plugin import PluginTestCase
 
 from quodlibet import library
@@ -19,7 +18,7 @@ class TMediaServer(PluginTestCase):
     @classmethod
     def setUpClass(cls):
         app.library = library.init()
-        cls.plugin = cls.plugins["mediaserver"]
+        cls.plugin = cls.plugins["mediaserver"].cls
 
     def setUp(self):
         self.m = self.plugin()
@@ -66,6 +65,3 @@ class TMediaServer(PluginTestCase):
         self.failIf(
             bus.name_has_owner("org.gnome.UPnP.MediaServer2.QuodLibet"))
         del self.m
-
-
-add(TMediaServer)
