@@ -4,15 +4,12 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 
-from tests import add
 from tests.plugin import PluginTestCase
 
 
 class TTestPlugins(PluginTestCase):
     def test_pickle(self):
-        plugin = self.plugins["pickle_test"]
+        plugin = self.plugins["pickle_test"].cls
         instance = plugin()
         instance.enabled()
         instance.disabled()
-
-add(TTestPlugins)
