@@ -1,10 +1,11 @@
-from tests import TestCase, add
+from tests import TestCase
 
 from quodlibet.browsers.filesystem import FileSystem
 from quodlibet.player.nullbe import NullPlayer
 from quodlibet.library import SongLibrary
 import quodlibet.config
 
+
 class TFileSystem(TestCase):
     def setUp(self):
         quodlibet.config.init()
@@ -18,4 +19,3 @@ class TFileSystem(TestCase):
     def tearDown(self):
         self.bar.destroy()
         quodlibet.config.quit()
-add(TFileSystem)
