@@ -3,6 +3,7 @@ from tests import TestCase, DATA_DIR, mkstemp
 import os
 
 from quodlibet import config
+from quodlibet.util.path import is_fsnative, fsnative
 from quodlibet.formats._audio import AudioFile
 from quodlibet.formats._audio import INTERN_NUM_DEFAULT
 
@@ -215,6 +216,16 @@ class TAudioFile(TestCase):
         self.failIf(song["artist"] in song.website())
         self.failUnless(song["labelid"] in song.website())
 
+    def test_lyric_filename(self):
+        song = AudioFile()
+        song["~filename"] = fsnative(u"filename")
+        self.assertTrue(is_fsnative(song.lyric_filename))
+        song["title"] = u"Title"
+        song["artist"] = u"Artist"
+        self.assertTrue(is_fsnative(song.lyric_filename))
+        song["lyricist"] = u"Lyricist"
+        self.assertTrue(is_fsnative(song.lyric_filename))
+
     def test_sanitize(self):
         q = AudioFile(quux)
         b = AudioFile(bar_1_1)
@@ -230,12 +241,31 @@ class TAudioFile(TestCase):
     def test_performers(self):
         q = AudioFile([("performer:vocals", "A"), ("performer:guitar", "B"),
                        ("performer", "C")])
-        self.failUnless("A (Vocals)" in q.list("~performers"))
-        self.failUnless("B (Guitar)" in q.list("~performers"))
-        self.failUnless("C" in q.list("~performers"))
-        self.failUnless("A (Vocals)" in q.list("~people"))
-        self.failUnless("B (Guitar)" in q.list("~people"))
-        self.failUnlessEqual(len(q.list("~performers")), 3)
+        self.failUnlessEqual(set(q.list("~performers")), set(["A", "B", "C"]))
+        self.failUnlessEqual(set(q.list("~performers:roles")),
+                             set(["A (Vocals)", "B (Guitar)", "C"]))
+
+    def test_people(self):
+        q = AudioFile([("performer:vocals", "A"), ("performer:guitar", "B"),
+                       ("performer", "C"), ("arranger", "A"),
+                       ("albumartist", "B"), ("artist", "C")])
+        self.failUnlessEqual(q.list("~people"), ["B", "C", "A"])
+        self.failUnlessEqual(q.list("~people:roles"),
+                             ["B (Guitar)", "C", "A (Arrangement, Vocals)"])
+
+    def test_peoplesort(self):
+        q = AudioFile([("performer:vocals", "The A"),
+                       ("performersort:vocals", "A, The"),
+                       ("performer:guitar", "The B"),
+                       ("performersort:guitar", "B, The"),
+                       ("performer", "The C"),
+                       ("performersort", "C, The"),
+                       ("albumartist", "The B"),
+                       ("albumartistsort", "B, The")])
+        self.failUnlessEqual(q.list("~peoplesort"),
+                             ["B, The", "C, The", "A, The"])
+        self.failUnlessEqual(q.list("~peoplesort:roles"),
+                             ["B, The (Guitar)", "C, The", "A, The (Vocals)"])
 
     def test_to_dump(self):
         dump = bar_1_1.to_dump()
@@ -434,6 +464,17 @@ class Treplay_gain(TestCase):
                         "replaygain_track_gain": "+1.0000001 dB",
                         "replaygain_track_peak": "0.9"}
         self.song = AudioFile(self.rg_data)
+        self.no_rg_song = AudioFile()
+
+    def test_no_rg_song(self):
+        scale = self.no_rg_song.replay_gain(["track"], 0, -6.0)
+        self.failUnlessAlmostEqual(scale, self.minus_6db)
+
+        scale = self.no_rg_song.replay_gain(["track"], +10, +10)
+        self.failUnlessEqual(scale, 1.0)
+
+        scale = self.no_rg_song.replay_gain(["track"], -16.0, +10)
+        self.failUnlessAlmostEqual(scale, self.minus_6db)
 
     def test_nogain(self):
         self.failUnlessEqual(self.song.replay_gain(["none", "track"]), 1)
