@@ -1,19 +1,33 @@
-from tests import add, TestCase
+from quodlibet.config import RATINGS
+from tests import TestCase, DATA_DIR, skipUnless, mkstemp, AbstractTestCase
 
 import os
 import sys
 import shutil
-import tempfile
 import base64
+import StringIO
 
 from quodlibet import config, const, formats
 from quodlibet.formats.xiph import OggFile, FLACFile, OggOpusFile, OggOpus
+from quodlibet.formats._image import EmbeddedImage, APICType
 
 from mutagen.flac import FLAC, Picture
 from mutagen.id3 import ID3, TIT2, ID3NoHeaderError
 from mutagen.oggvorbis import OggVorbis
 
 
+def _get_jpeg(size=5):
+    from gi.repository import GdkPixbuf
+    pb = GdkPixbuf.Pixbuf.new(
+        GdkPixbuf.Colorspace.RGB, False, 8, size, size)
+    fd, fn = mkstemp()
+    pb.savev(fn, "jpeg", [], [])
+    with os.fdopen(fd) as h:
+        data = h.read()
+    os.unlink(fn)
+    return data
+
+
 class TXiphPickle(TestCase):
     # make sure the classes are available at the old paths
     # so unpickling old libraries works.
@@ -28,10 +42,8 @@ class TXiphPickle(TestCase):
         mod = sys.modules["formats.oggvorbis"]
         self.failUnless(mod.OggFile is OggFile)
 
-add(TXiphPickle)
 
-
-class TVCFile(TestCase):
+class TVCFile(AbstractTestCase):
     # Mixin to test Vorbis writing features
 
     def setUp(self):
@@ -49,11 +61,11 @@ class TVCFile(TestCase):
         config.set("editing", "save_email", "foo@bar.org")
         self.song["~#rating"] = 0.2
         self.song.write()
-        self.song["~#rating"] = const.DEFAULT_RATING
+        self.song["~#rating"] = RATINGS.default
         self.song.write()
         song = type(self.song)(self.filename)
         config.set("editing", "save_email", const.EMAIL)
-        self.failUnlessEqual(song("~#rating"), const.DEFAULT_RATING)
+        self.failUnlessEqual(song("~#rating"), RATINGS.default)
 
     def test_new_email_rating(self):
         config.set("editing", "save_email", "foo@bar.org")
@@ -77,7 +89,7 @@ class TVCFile(TestCase):
         self.song.write()
         config.set("editing", "save_email", const.EMAIL)
         song = type(self.song)(self.filename)
-        self.failUnlessEqual(song("~#rating"), const.DEFAULT_RATING)
+        self.failUnlessEqual(song("~#rating"), RATINGS.default)
 
         song.write()
         config.set("editing", "save_email", "foo@bar.org")
@@ -89,7 +101,7 @@ class TVCFile(TestCase):
         self.song["~#rating"] = "invalid"
         self.song.write()
         song = type(self.song)(self.filename)
-        self.failUnlessEqual(song("~#rating"), const.DEFAULT_RATING)
+        self.failUnlessEqual(song("~#rating"), RATINGS.default)
 
     def test_huge_playcount(self):
         count = 1000000000000000L
@@ -102,18 +114,36 @@ class TVCFile(TestCase):
         for bad in ["rating", "playcount", "rating:foo", "playcount:bar"]:
             self.failIf(self.song.can_change(bad))
 
+    def test_parameter_ci(self):
+        for bad in ["ratinG", "plaYcount", "raTing:foo", "playCount:bar"]:
+            self.failIf(self.song.can_change(bad))
+
+    def test_case_insensitive(self):
+        self.song["foo"] = "1"
+        self.song["FOO"] = "1"
+        self.song.write()
+        self.song.reload()
+        self.failUnlessEqual(self.song.list("foo"), ["1", "1"])
+
+    def test_case_insensitive_total(self):
+        self.song["TRacKNUMBER"] = "1/10"
+        self.song.write()
+        self.song.reload()
+        self.failUnlessEqual(self.song["tracknumber"], "1/10")
+
     def test_dont_save(self):
         config.set("editing", "save_to_songs", "false")
         self.song["~#rating"] = 1.0
         self.song.write()
         song = type(self.song)(self.filename)
         config.set("editing", "save_to_songs", "true")
-        self.failUnlessEqual(song("~#rating"), const.DEFAULT_RATING)
+        self.failUnlessEqual(song("~#rating"), RATINGS.default)
 
     def test_can_change(self):
         self.failUnless(self.song.can_change())
 
-class TTotalTagsBase(TestCase):
+
+class TTotalTagsBase(AbstractTestCase):
     """Test conversation between the tracknumber/totaltracks/tracktotal
     format and the tracknumber="x/y" format.
 
@@ -125,8 +155,9 @@ class TTotalTagsBase(TestCase):
 
     def setUp(self):
         config.init()
-        self.filename = tempfile.mkstemp(".ogg")[1]
-        shutil.copy(os.path.join('tests', 'data', 'empty.ogg'), self.filename)
+        h, self.filename = mkstemp(".ogg")
+        os.close(h)
+        shutil.copy(os.path.join(DATA_DIR, 'empty.ogg'), self.filename)
 
     def tearDown(self):
         os.unlink(self.filename)
@@ -239,21 +270,20 @@ class TTrackTotal(TTotalTagsBase):
     MAIN = "tracktotal"
     FALLBACK = "totaltracks"
     SINGLE = "tracknumber"
-add(TTrackTotal)
 
 
 class TDiscTotal(TTotalTagsBase):
     MAIN = "disctotal"
     FALLBACK = "totaldiscs"
     SINGLE = "discnumber"
-add(TDiscTotal)
 
 
 class TFLACFile(TVCFile):
     def setUp(self):
         TVCFile.setUp(self)
-        self.filename = tempfile.mkstemp(".flac")[1]
-        shutil.copy(os.path.join('tests', 'data', 'empty.flac'), self.filename)
+        h, self.filename = mkstemp(".flac")
+        os.close(h)
+        shutil.copy(os.path.join(DATA_DIR, 'empty.flac'), self.filename)
         self.song = FLACFile(self.filename)
 
     def test_mime(self):
@@ -280,27 +310,49 @@ class TFLACFile(TVCFile):
     def tearDown(self):
         os.unlink(self.filename)
         config.quit()
-add(TFLACFile)
 
 
-class TVCCover(TestCase):
+class TVCCover(AbstractTestCase):
     def setUp(self):
         config.init()
 
-    def __get_jpeg(self, size=5):
-        from gi.repository import GdkPixbuf
-        pb = GdkPixbuf.Pixbuf.new(GdkPixbuf.Colorspace.RGB, False, 8, size, size)
-        fn = tempfile.NamedTemporaryFile()
-        pb.savev(fn.name, "jpeg", [], [])
-        return fn.read()
+    def test_can_change_images(self):
+        song = self.QLType(self.filename)
+        self.assertTrue(song.can_change_images)
 
     def test_no_cover(self):
         song = self.QLType(self.filename)
         self.failIf(song("~picture"))
-        self.failIf(song.find_cover())
+        self.failIf(song.get_primary_image())
+
+    def test_get_images(self):
+        # coverart + coverartmime
+        data = _get_jpeg()
+        song = self.MutagenType(self.filename)
+        song["coverart"] = base64.b64encode(data)
+        song["coverartmime"] = "image/jpeg"
+        song.save()
+
+        song = self.QLType(self.filename)
+        self.assertEqual(len(song.get_images()), 1)
+        self.assertEqual(song.get_images()[0].mime_type, "image/jpeg")
+
+        # metadata_block_picture
+        pic = Picture()
+        pic.data = _get_jpeg()
+        pic.type = APICType.COVER_FRONT
+        b64pic_cover = base64.b64encode(pic.write())
+
+        song = self.MutagenType(self.filename)
+        song["metadata_block_picture"] = [b64pic_cover]
+        song.save()
+
+        song = self.QLType(self.filename)
+        self.assertEqual(len(song.get_images()), 2)
+        self.assertEqual(song.get_images()[0].type, APICType.COVER_FRONT)
 
     def test_handle_old_coverart(self):
-        data = self.__get_jpeg()
+        data = _get_jpeg()
         song = self.MutagenType(self.filename)
         song["coverart"] = base64.b64encode(data)
         song["coverartmime"] = "image/jpeg"
@@ -312,9 +364,10 @@ class TVCCover(TestCase):
         self.failIf(song("coverartmime"))
         song.write()
 
-        fn = song.find_cover()
+        self.assertEqual(song.get_primary_image().mime_type, "image/jpeg")
+        fn = song.get_primary_image().file
         cov_data = fn.read()
-        self.failUnlessEqual(data,cov_data)
+        self.failUnlessEqual(data, cov_data)
 
         song = self.MutagenType(self.filename)
         self.failUnlessEqual(base64.b64decode(song["coverart"][0]), data)
@@ -329,7 +382,7 @@ class TVCCover(TestCase):
         song = self.QLType(self.filename)
         self.failUnlessEqual(song("~picture"), "y")
         self.failIf(song("coverart"))
-        self.failIf(song.find_cover())
+        self.failIf(song.get_primary_image())
         self.failIf(song("~picture"))
         song.write()
 
@@ -338,14 +391,14 @@ class TVCCover(TestCase):
 
     def test_handle_picture_block(self):
         pic = Picture()
-        pic.data = self.__get_jpeg()
-        pic.type = 3
+        pic.data = _get_jpeg()
+        pic.type = APICType.COVER_FRONT
         b64pic_cover = base64.b64encode(pic.write())
 
         pic2 = Picture()
-        pic2.data = self.__get_jpeg(size=6)
-        pic2.type = 4
-        b64pic_other= base64.b64encode(pic2.write())
+        pic2.data = _get_jpeg(size=6)
+        pic2.type = APICType.COVER_BACK
+        b64pic_other = base64.b64encode(pic2.write())
 
         song = self.MutagenType(self.filename)
         song["metadata_block_picture"] = [b64pic_other, b64pic_cover]
@@ -354,7 +407,7 @@ class TVCCover(TestCase):
         song = self.QLType(self.filename)
         self.failUnlessEqual(song("~picture"), "y")
 
-        fn = song.find_cover()
+        fn = song.get_primary_image().file
         self.failUnlessEqual(pic.data, fn.read())
         song.write()
 
@@ -365,7 +418,7 @@ class TVCCover(TestCase):
         song.save()
 
         song = self.QLType(self.filename)
-        fn = song.find_cover()
+        fn = song.get_primary_image().file
         self.failUnlessEqual(pic2.data, fn.read())
 
     def test_handle_invalid_picture_block(self):
@@ -377,13 +430,44 @@ class TVCCover(TestCase):
         song = self.QLType(self.filename)
         self.failUnlessEqual(song("~picture"), "y")
         self.failIf(song("metadata_block_picture"))
-        self.failIf(song.find_cover())
+        self.failIf(song.get_primary_image())
         self.failIf(song("~picture"))
         song.write()
 
         song = self.MutagenType(self.filename)
         self.failUnlessEqual(song["metadata_block_picture"][0], crap)
 
+    def test_handle_invalid_flac_picture(self):
+        crap = ".-a,a.f,afa-,.-"
+        song = self.MutagenType(self.filename)
+        song["metadata_block_picture"] = base64.b64encode(crap)
+        song.save()
+        song = self.QLType(self.filename)
+        self.failIf(song.get_primary_image())
+        self.failIf(song.get_images())
+
+    def test_set_image(self):
+        data = _get_jpeg()
+        song = self.MutagenType(self.filename)
+        song["coverart"] = base64.b64encode(data)
+        song["coverartmime"] = "image/jpeg"
+        song.save()
+
+        fileobj = StringIO.StringIO("foo")
+        image = EmbeddedImage(fileobj, "image/jpeg", 10, 10, 8)
+
+        song = self.QLType(self.filename)
+        self.assertTrue(song.has_images)
+        self.assertTrue(song.get_primary_image())
+        self.assertTrue(song.has_images)
+        song.set_image(image)
+        self.assertTrue(song.has_images)
+        self.assertEqual(song.get_primary_image().width, 10)
+
+        song = self.MutagenType(self.filename)
+        self.assertTrue("coverart" not in song)
+        self.assertTrue("coverartmime" not in song)
+
     def tearDown(self):
         os.unlink(self.filename)
         config.quit()
@@ -392,30 +476,58 @@ class TVCCover(TestCase):
 class TVCCoverOgg(TVCCover):
     def setUp(self):
         TVCCover.setUp(self)
-        self.filename = tempfile.mkstemp(".ogg")[1]
-        shutil.copy(os.path.join('tests', 'data', 'empty.ogg'), self.filename)
+        h, self.filename = mkstemp(".ogg")
+        os.close(h)
+        shutil.copy(os.path.join(DATA_DIR, 'empty.ogg'), self.filename)
         self.MutagenType = OggVorbis
         self.QLType = OggFile
-add(TVCCoverOgg)
 
 
 class TVCCoverFlac(TVCCover):
     def setUp(self):
         TVCCover.setUp(self)
-        self.filename = tempfile.mkstemp(".flac")[1]
-        shutil.copy(os.path.join('tests', 'data', 'empty.flac'), self.filename)
+        h, self.filename = mkstemp(".flac")
+        os.close(h)
+        shutil.copy(os.path.join(DATA_DIR, 'empty.flac'), self.filename)
         self.MutagenType = FLAC
         self.QLType = FLACFile
-add(TVCCoverFlac)
 
 
 class TFlacPicture(TestCase):
     def setUp(self):
         config.init()
-        self.filename = tempfile.mkstemp(".flac")[1]
-        shutil.copy(os.path.join('tests', 'data', 'empty.flac'), self.filename)
+        h, self.filename = mkstemp(".flac")
+        os.close(h)
+        shutil.copy(os.path.join(DATA_DIR, 'empty.flac'), self.filename)
 
-    def test_picture(self):
+    def test_get_images(self):
+        pic = Picture()
+        pic.data = _get_jpeg()
+        pic.type = APICType.COVER_FRONT
+        b64pic_cover = base64.b64encode(pic.write())
+
+        # metadata_block_picture
+        song = FLAC(self.filename)
+        song["metadata_block_picture"] = [b64pic_cover]
+        song.save()
+
+        song = FLACFile(self.filename)
+        self.assertEqual(len(song.get_images()), 1)
+        self.assertEqual(song.get_images()[0].type, APICType.COVER_FRONT)
+
+        # flac Picture
+        song = FLAC(self.filename)
+        pic = Picture()
+        pic.data = _get_jpeg()
+        pic.type = APICType.COVER_BACK
+        song.add_picture(pic)
+        song.save()
+
+        song = FLACFile(self.filename)
+        self.assertEqual(len(song.get_images()), 2)
+        self.assertEqual(song.get_images()[-1].type, APICType.COVER_BACK)
+
+    def test_get_image(self):
         data = "abc"
         song = FLAC(self.filename)
         pic = Picture()
@@ -425,33 +537,58 @@ class TFlacPicture(TestCase):
 
         song = FLACFile(self.filename)
         self.failUnless(song("~picture"))
-        fn = song.find_cover()
+        fn = song.get_primary_image().file
         self.failUnlessEqual(fn.read(), pic.data)
 
+    def test_clear_images(self):
+        data = "abc"
+        song = FLAC(self.filename)
+        pic = Picture()
+        pic.data = data
+        song.add_picture(pic)
+        song.save()
+
+        song = FLACFile(self.filename)
+        self.assertTrue(song.get_primary_image())
+        song.clear_images()
+        song.clear_images()
+        song = FLACFile(self.filename)
+        self.assertFalse(song.get_primary_image())
+
+    def test_set_image(self):
+        fileobj = StringIO.StringIO("foo")
+        image = EmbeddedImage(fileobj, "image/jpeg", 10, 10, 8)
+
+        song = FLACFile(self.filename)
+        self.assertFalse(song.get_primary_image())
+        song.set_image(image)
+        self.assertEqual(song.get_primary_image().width, 10)
+
     def tearDown(self):
         os.unlink(self.filename)
         config.quit()
-add(TFlacPicture)
 
 
 class TOggFile(TVCFile):
     def setUp(self):
         TVCFile.setUp(self)
-        self.filename = tempfile.mkstemp(".ogg")[1]
-        shutil.copy(os.path.join('tests', 'data', 'empty.ogg'), self.filename)
+        h, self.filename = mkstemp(".ogg")
+        os.close(h)
+        shutil.copy(os.path.join(DATA_DIR, 'empty.ogg'), self.filename)
         self.song = OggFile(self.filename)
 
     def tearDown(self):
         os.unlink(self.filename)
         config.quit()
-add(TOggFile)
 
 
+@skipUnless(OggOpus, "Ogg Opus mutagen support missing")
 class TOggOpusFile(TVCFile):
     def setUp(self):
         TVCFile.setUp(self)
-        self.filename = tempfile.mkstemp(".ogg")[1]
-        shutil.copy(os.path.join('tests', 'data', 'empty.opus'), self.filename)
+        h, self.filename = mkstemp(".ogg")
+        os.close(h)
+        shutil.copy(os.path.join(DATA_DIR, 'empty.opus'), self.filename)
         self.song = OggOpusFile(self.filename)
 
     def test_length(self):
@@ -461,7 +598,3 @@ class TOggOpusFile(TVCFile):
     def tearDown(self):
         os.unlink(self.filename)
         config.quit()
-
-if OggOpus:
-    add(TOggOpusFile)
-
