@@ -5,23 +5,28 @@ import shutil
 from quodlibet import config
 from quodlibet.formats._audio import AudioFile
 
-from tests import TestCase, add
-from tempfile import mkstemp
+from tests import TestCase, DATA_DIR, mkstemp
+from helper import capture_output
 
 from quodlibet.library.libraries import *
 
+
 class Fake(int):
     def __init__(self, _):
         self.key = int(self)
 
+
 def Frange(*args):
     return map(Fake, range(*args))
 
+
 class FakeSong(Fake):
     def list(self, tag):
         # Turn tag_values into a less-than query, for testing.
-        if tag <= self: return []
-        else: return [int(self)]
+        if tag <= self:
+            return []
+        else:
+            return [int(self)]
 
     def rename(self, newname):
         self.key = newname
@@ -41,6 +46,7 @@ class AlbumSong(AudioFile):
             self["album"] = album
         self["labelid"] = self["album"]
 
+
 class FakeSongFile(FakeSong):
     _valid = True
     _exists = True
@@ -54,8 +60,10 @@ class FakeSongFile(FakeSong):
         return self._exists
 
     def reload(self):
-        if self._exists: self._valid = True
-        else: raise IOError("doesn't exist")
+        if self._exists:
+            self._valid = True
+        else:
+            raise IOError("doesn't exist")
 
     def mounted(self):
         return self._mounted
@@ -65,12 +73,15 @@ class FakeSongFile(FakeSong):
 def FSFrange(*args):
     return map(FakeSongFile, range(*args))
 
+
 def FSrange(*args):
     return map(FakeSong, range(*args))
 
+
 def ASrange(*args):
     return map(AlbumSong, range(*args))
 
+
 class TLibrary(TestCase):
     Fake = Fake
     Frange = staticmethod(Frange)
@@ -95,7 +106,7 @@ class TLibrary(TestCase):
 
     def test_remove(self):
         self.library.add(self.Frange(10))
-        self.library.remove(self.Frange(3, 6))
+        self.assertTrue(self.library.remove(self.Frange(3, 6)))
         self.failUnlessEqual(self.removed, self.Frange(3, 6))
 
         # Neither the objects nor their keys should be present.
@@ -105,23 +116,26 @@ class TLibrary(TestCase):
         self.failUnless(6 in self.library)
 
     def test_remove_when_not_present(self):
-        self.failUnlessRaises(KeyError, self.library.remove, [self.Fake(12)])
+        self.assertFalse(self.library.remove([self.Fake(12)]))
 
     def test_changed(self):
         self.library.add(self.Frange(10))
         self.library.changed(self.Frange(5))
-        while Gtk.events_pending(): Gtk.main_iteration()
+        while Gtk.events_pending():
+            Gtk.main_iteration()
         self.failUnlessEqual(self.changed, self.Frange(5))
 
     def test_changed_not_present(self):
         self.library.add(self.Frange(10))
         self.library.changed(self.Frange(2, 20, 3))
-        while Gtk.events_pending(): Gtk.main_iteration()
-        self.failUnlessEqual(self.changed, [2, 5, 8])
+        while Gtk.events_pending():
+            Gtk.main_iteration()
+        self.failUnlessEqual(set(self.changed), set([2, 5, 8]))
 
     def test_changed_none_present(self):
         self.library.changed(self.Frange(5))
-        while Gtk.events_pending(): Gtk.main_iteration()
+        while Gtk.events_pending():
+            Gtk.main_iteration()
 
     def test___iter__(self):
         self.library.add(self.Frange(10))
@@ -213,8 +227,6 @@ class TLibrary(TestCase):
 
     def tearDown(self):
         self.library.destroy()
-add(TLibrary)
-
 
 
 class TPicklingMixin(TestCase):
@@ -229,7 +241,8 @@ class TPicklingMixin(TestCase):
             self.items = self._contents.items
 
         def add(self, items):
-            for item in items: self._contents[item.key] = item
+            for item in items:
+                self._contents[item.key] = item
 
     Library = PicklingMockLibrary
     Frange = staticmethod(Frange)
@@ -239,8 +252,8 @@ class TPicklingMixin(TestCase):
 
     def test_save_load(self):
         fd, filename = mkstemp()
+        os.close(fd)
         try:
-            os.close(fd)
             self.library.add(Frange(30))
             self.library.save(filename)
 
@@ -250,7 +263,6 @@ class TPicklingMixin(TestCase):
                 sorted(self.library.items()), sorted(library.items()))
         finally:
             os.unlink(filename)
-add(TPicklingMixin)
 
 
 class TSongLibrary(TLibrary):
@@ -271,19 +283,27 @@ class TSongLibrary(TLibrary):
         song = FakeSong(10)
         self.library.add([song])
         self.library.rename(song, 20)
-        while Gtk.events_pending(): Gtk.main_iteration()
+        while Gtk.events_pending():
+            Gtk.main_iteration()
         self.failUnless(song in self.changed)
         self.failUnless(song in self.library)
         self.failUnless(song.key in self.library)
         self.failUnlessEqual(song.key, 20)
 
+    def test_rename_changed(self):
+        song = FakeSong(10)
+        self.library.add([song])
+        changed = set()
+        self.library.rename(song, 20, changed=changed)
+        self.assertEqual(len(changed), 1)
+        self.assertTrue(song in changed)
+
     def test_tag_values(self):
         self.library.add(self.Frange(30))
         del(self.added[:])
         self.failUnlessEqual(sorted(self.library.tag_values(10)), range(10))
         self.failUnlessEqual(sorted(self.library.tag_values(0)), [])
         self.failIf(self.changed or self.added or self.removed)
-add(TSongLibrary)
 
 
 class TFileLibrary(TLibrary):
@@ -344,7 +364,14 @@ class TFileLibrary(TLibrary):
         self.library._load_init([new])
         self.failUnlessEqual(self.library.values(), [new])
 
-add(TFileLibrary)
+    def test_reload(self):
+        new = self.Fake(200)
+        self.library.add([new])
+        changed = set()
+        removed = set()
+        self.library.reload(new, changed=changed, removed=removed)
+        self.assertTrue(new in changed)
+        self.assertFalse(removed)
 
 
 class TSongFileLibrary(TSongLibrary):
@@ -377,7 +404,9 @@ class TSongFileLibrary(TSongLibrary):
             print_exc = util.print_exc
             util.print_exc = lambda *args, **kwargs: None
             new = self.Fake(100)
-            def error(): raise IOError
+
+            def error():
+                raise IOError
             new.reload = error
             new._valid = False
             changed, removed = self.library._load_item(new)
@@ -402,7 +431,8 @@ class TSongFileLibrary(TSongLibrary):
 
     def __get_file(self):
         fd, filename = mkstemp(".flac")
-        shutil.copy(os.path.join('tests', 'data', 'empty.flac'), filename)
+        os.close(fd)
+        shutil.copy(os.path.join(DATA_DIR, 'empty.flac'), filename)
         return filename
 
     def test_add_filename(self):
@@ -429,7 +459,8 @@ class TSongFileLibrary(TSongLibrary):
             self.failUnlessEqual(2, len(self.library))
             os.unlink(filename)
 
-            ret = self.library.add_filename("")
+            with capture_output():
+                ret = self.library.add_filename("")
             self.failIf(ret)
             self.failUnlessEqual(len(self.added), 2)
             self.failUnlessEqual(2, len(self.library))
@@ -437,8 +468,6 @@ class TSongFileLibrary(TSongLibrary):
         finally:
             config.quit()
 
-add(TSongFileLibrary)
-
 
 class TAlbumLibrary(TestCase):
     Fake = FakeSong
@@ -485,7 +514,7 @@ class TAlbumLibrary(TestCase):
         self.failUnlessEqual(self.library[key].key, key)
 
     def test_keys(self):
-        self.failUnless(len(self.library.keys()),3)
+        self.failUnless(len(self.library.keys()), 3)
 
     def test_has_key(self):
         key = self.underlying.get("file_1.mp3").album_key
@@ -528,8 +557,6 @@ class TAlbumLibrary(TestCase):
         # It shouldn't implement FileLibrary etc
         self.failIf(getattr(self.library, "filename", None))
 
-add(TAlbumLibrary)
-
 
 class TAlbumLibrarySignals(TestCase):
     def setUp(self):
@@ -586,5 +613,3 @@ class TAlbumLibrarySignals(TestCase):
         for s in self._sigs:
             self.lib.disconnect(s)
         self.lib.destroy()
-
-add(TAlbumLibrarySignals)
