@@ -6,35 +6,18 @@
 
 import os
 import subprocess
-import tempfile
 import imp
 import shutil
-import contextlib
-import StringIO
 import sys
 
-from tests import TestCase, add
+from tests import TestCase, DATA_DIR, mkstemp
+from helper import capture_output
 
 import quodlibet
 from quodlibet import config
 from quodlibet.formats import MusicFile
 
 
-@contextlib.contextmanager
-def capture_output():
-    err = StringIO.StringIO()
-    out = StringIO.StringIO()
-    old_err = sys.stderr
-    old_out = sys.stdout
-    sys.stderr = err
-    sys.stdout = out
-
-    yield (out, err)
-
-    sys.stderr = old_err
-    sys.stdout = old_out
-
-
 def call(args=None):
     path = os.path.join(os.path.dirname(quodlibet.__path__[0]), "operon.py")
     mod = imp.load_source("operon", path)
@@ -51,22 +34,32 @@ def call(args=None):
 class TOperonBase(TestCase):
     def setUp(self):
         config.init()
-        self.f = tempfile.mkstemp(".ogg")[1]
-        self.f2 = tempfile.mkstemp(".mp3")[1]
-        shutil.copy(os.path.join('tests', 'data', 'silence-44-s.ogg'), self.f)
-        shutil.copy(os.path.join('tests', 'data', 'silence-44-s.mp3'), self.f2)
+        fd, self.f = mkstemp(".ogg")
+        os.close(fd)
+        fd, self.f2 = mkstemp(".mp3")
+        os.close(fd)
+        fd, self.f3 = mkstemp(".mp3")
+        os.write(fd, "garbage")
+        os.close(fd)
+        shutil.copy(os.path.join(DATA_DIR, 'silence-44-s.ogg'), self.f)
+        shutil.copy(os.path.join(DATA_DIR, 'silence-44-s.mp3'), self.f2)
         self.s = MusicFile(self.f)
         self.s2 = MusicFile(self.f2)
 
     def tearDown(self):
         os.unlink(self.f)
         os.unlink(self.f2)
+        os.unlink(self.f3)
         config.quit()
 
     def check_true(self, args, so, se, **kwargs):
+        """Assert success status code"""
+
         return self._check(args, True, so, se, **kwargs)
 
     def check_false(self, args, so, se, **kwargs):
+        """Assert error status code"""
+
         return self._check(args, False, so, se, **kwargs)
 
     def _check(self, args, success, so, se):
@@ -98,7 +91,6 @@ class TOperonMain(TOperonBase):
         self.check_true(["-v", "help", "help"], True, False)
         self.check_false(["--foobar", "help", "help"], False, True)
         self.check_true(["--version"], True, False)
-add(TOperonMain)
 
 
 class TOperonAdd(TOperonBase):
@@ -126,12 +118,15 @@ class TOperonAdd(TOperonBase):
         self.check_false(["add", "playcount", "bar", self.f], False, True)
 
     def test_permissions(self):
-        os.chmod(self.f, 0000)
-        self.check_false(["add", "foo", "bar", self.f, self.f],
-                         False, True)
-        os.chmod(self.f, 0444)
-        self.check_false(["add", "foo", "bar", self.f, self.f], False, True)
-add(TOperonAdd)
+        try:
+            os.chmod(self.f, 0000)
+            self.check_false(["add", "foo", "bar", self.f, self.f],
+                             False, True)
+            os.chmod(self.f, 0444)
+            self.check_false(["add", "foo", "bar", self.f, self.f],
+                             False, True)
+        finally:
+            os.chmod(self.f, 0666)
 
 
 class TOperonPrint(TOperonBase):
@@ -150,11 +145,24 @@ class TOperonPrint(TOperonBase):
                                True, False)
         self.failUnlessEqual(o.splitlines(), ["Silence", "Silence"])
 
+    def test_print_invalid(self):
+        # passing a song which can't be loaded results in fail
+        self.check_false(["print", self.f3], False, True)
+
+        # in case some fail and some don't, print the error messages for
+        # the failed ones, the patterns for the working ones and return
+        # an error status
+        o, e = self.check_false(["print", self.f3, self.f2], True, True)
+        self.assertTrue("Quod Libet Test Data" in o)
+        self.assertTrue(os.path.basename(self.f3) in e)
+
     def test_permissions(self):
+        # doesn't prevent reading under wine..
+        if os.name == "nt":
+            return
         os.chmod(self.f, 0000)
         self.check_false(["print", "-p", "<title>", self.f],
                          False, True)
-add(TOperonPrint)
 
 
 class TOperonRemove(TOperonBase):
@@ -201,8 +209,6 @@ class TOperonRemove(TOperonBase):
         self.s.reload()
         self.failIf(self.s.list("test"))
 
-add(TOperonRemove)
-
 
 class TOperonClear(TOperonBase):
     # [--dry-run] [-a | -e <pattern> | <tag>] <file> [<files>]
@@ -248,7 +254,6 @@ class TOperonClear(TOperonBase):
         self.check(["clear", "artist", self.f], True, output=False)
         self.s.reload()
         self.failUnlessEqual(len(self.s.realkeys()), old_len - 1)
-add(TOperonClear)
 
 
 class TOperonSet(TOperonBase):
@@ -277,7 +282,6 @@ class TOperonSet(TOperonBase):
         self.check_true(["set", "artist", "foobar", self.f], False, False)
         self.s.reload()
         self.failUnlessEqual(self.s["artist"], "foobar")
-add(TOperonSet)
 
 
 class TOperonDump(TOperonBase):
@@ -292,7 +296,6 @@ class TOperonDump(TOperonBase):
         o, e = self.check_true(["dump", self.f], True, False)
         internal = filter(lambda x: x.startswith("~"), o.splitlines())
         self.failIf(internal)
-add(TOperonDump)
 
 
 class TOperonCopy(TOperonBase):
@@ -306,7 +309,8 @@ class TOperonCopy(TOperonBase):
         self.check_true(["-v", "copy", self.f, self.f2], False, True)
 
     def test_simple(self):
-        map(self.s2.__delitem__, self.s2.realkeys())
+        for key in self.s2.realkeys():
+            del self.s2[key]
         self.s2.write()
         self.s2.reload()
         self.failIf(self.s2.realkeys())
@@ -328,13 +332,13 @@ class TOperonCopy(TOperonBase):
         self.failUnlessEqual(len(self.s2.list("genre")), 2)
 
     def test_dry_run(self):
-        map(self.s2.__delitem__, self.s2.realkeys())
+        for key in self.s2.realkeys():
+            del self.s2[key]
         self.s2.write()
         self.s2.reload()
         self.check_true(["copy", "--dry-run", self.f, self.f2], False, True)
         self.s2.reload()
         self.failIf(self.s2.realkeys())
-add(TOperonCopy)
 
 
 class TOperonInfo(TOperonBase):
@@ -360,7 +364,6 @@ class TOperonInfo(TOperonBase):
         self.check_true(["info", "-t", "-cdesc,value", self.f], True, False)
         self.check_true(["info", "-t", "-cvalue, desc", self.f], True, False)
         self.check_false(["info", "-t", "-cfoo", self.f], False, True)
-add(TOperonInfo)
 
 
 class TOperonList(TOperonBase):
@@ -393,7 +396,6 @@ class TOperonList(TOperonBase):
         d = self.check_true(["list", "-t", "-cvalue", self.f], True, False)[0]
         lines = d.splitlines()
         self.assertTrue("a\\:bc\\\\\\:" in lines)
-add(TOperonList)
 
 
 class TOperonTags(TOperonBase):
@@ -416,4 +418,146 @@ class TOperonTags(TOperonBase):
         self.check_true(["tags", "-t", "-cdesc,tag"], True, False)
         self.check_true(["tags", "-t", "-ctag, desc"], True, False)
         self.check_false(["tags", "-t", "-cfoo"], False, True)
-add(TOperonTags)
+
+
+class TOperonImageExtract(TOperonBase):
+    # [--dry-run] [--primary] [-d <destination>] <file> [<files>]
+
+    def setUp(self):
+        super(TOperonImageExtract, self).setUp()
+
+        h, self.fcover = mkstemp(".wma")
+        os.close(h)
+        shutil.copy(os.path.join(DATA_DIR, 'test-2.wma'), self.fcover)
+        self.cover = MusicFile(self.fcover)
+
+    def tearDown(self):
+        os.unlink(self.fcover)
+
+        super(TOperonImageExtract, self).tearDown()
+
+    def test_misc(self):
+        self.check_true(["image-extract", "-h"], True, False)
+        self.check_true(["image-extract", self.f], False, False)
+        self.check_true(["image-extract", self.f, self.f2], False, False)
+        self.check_false(["image-extract"], False, True)
+
+    def test_extract_all(self):
+        target_dir = os.path.dirname(self.fcover)
+        self.check_true(["image-extract", "-d", target_dir, self.fcover],
+                        False, False)
+
+        self.assertEqual(len(self.cover.get_images()), 1)
+        image = self.cover.get_primary_image()
+
+        name = os.path.splitext(os.path.basename(self.fcover))[0]
+
+        expected = "%s-00.%s" % (name, image.extensions[0])
+        expected_path = os.path.join(target_dir, expected)
+
+        self.assertTrue(os.path.exists(expected_path))
+
+        with open(expected_path, "rb") as h:
+            self.assertEqual(h.read(), image.file.read())
+
+    def test_extract_primary(self):
+        target_dir = os.path.dirname(self.fcover)
+        self.check_true(
+            ["image-extract", "-d", target_dir, "--primary", self.fcover],
+            False, False)
+
+        self.assertEqual(len(self.cover.get_images()), 1)
+        image = self.cover.get_primary_image()
+
+        name = os.path.splitext(os.path.basename(self.fcover))[0]
+
+        expected = "%s.%s" % (name, image.extensions[0])
+        expected_path = os.path.join(target_dir, expected)
+
+        self.assertTrue(os.path.exists(expected_path))
+
+        with open(expected_path, "rb") as h:
+            self.assertEqual(h.read(), image.file.read())
+
+
+class TOperonImageSet(TOperonBase):
+    # <image-file> <file> [<files>]
+
+    def setUp(self):
+        super(TOperonImageSet, self).setUp()
+        from gi.repository import GdkPixbuf
+
+        h, self.filename = mkstemp(".png")
+        os.close(h)
+        wide = GdkPixbuf.Pixbuf.new(GdkPixbuf.Colorspace.RGB, True, 8, 150, 10)
+        wide.savev(self.filename, "png", [], [])
+
+        h, self.fcover = mkstemp(".wma")
+        os.close(h)
+        shutil.copy(os.path.join(DATA_DIR, 'test-2.wma'), self.fcover)
+        self.cover = MusicFile(self.fcover)
+
+    def tearDown(self):
+        os.unlink(self.fcover)
+        os.unlink(self.filename)
+        super(TOperonImageSet, self).tearDown()
+
+    def test_misc(self):
+        self.check_true(["image-set", "-h"], True, False)
+        self.check_false(["image-set", self.fcover], False, True)
+        self.check_false(["image-set"], False, True)
+        self.check_false(["image-set", self.filename], False, True)
+
+    def test_not_supported(self):
+        path = os.path.join(DATA_DIR, 'test.mid')
+        out, err = self.check_false(
+            ["image-set", self.filename, path], False, True)
+        self.assertTrue("supported" in err)
+
+    def test_set(self):
+        self.check_true(["image-set", self.filename, self.fcover],
+                        False, False)
+        self.check_true(["-v", "image-set", self.filename, self.fcover],
+                        False, True)
+
+        self.cover.reload()
+        images = self.cover.get_images()
+        self.assertEqual(len(images), 1)
+
+        with open(self.filename, "rb") as h:
+            self.assertEqual(h.read(), images[0].file.read())
+
+
+class TOperonImageClear(TOperonBase):
+    # <image-file> <file> [<files>]
+
+    def setUp(self):
+        super(TOperonImageClear, self).setUp()
+        fd, self.fcover = mkstemp(".wma")
+        os.close(fd)
+        shutil.copy(os.path.join(DATA_DIR, 'test-2.wma'), self.fcover)
+        self.cover = MusicFile(self.fcover)
+
+    def tearDown(self):
+        os.unlink(self.fcover)
+        super(TOperonImageClear, self).tearDown()
+
+    def test_misc(self):
+        self.check_true(["image-clear", "-h"], True, False)
+        self.check_true(["image-clear", self.fcover], False, False)
+        self.check_false(["image-clear"], False, True)
+
+    def test_not_supported(self):
+        path = os.path.join(DATA_DIR, 'test.mid')
+        out, err = self.check_false(["image-clear", path], False, True)
+        self.assertTrue("supported" in err)
+
+    def test_clear(self):
+        images = self.cover.get_images()
+        self.assertEqual(len(images), 1)
+
+        self.check_true(["image-clear", self.fcover], False, False)
+
+        self.cover.reload()
+        images = self.cover.get_images()
+        self.assertEqual(len(images), 0)
