@@ -1,18 +1,19 @@
-from tests import TestCase, add
+from tests import TestCase, mkstemp
 
 import os
-import tempfile
 
 from quodlibet.qltk.cbes import ComboBoxEntrySave, StandaloneEditor
 import quodlibet.config
 
+
 class TComboBoxEntrySave(TestCase):
     memory = "pattern 1\npattern 2\n"
     saved = "pattern text\npattern name\n"
 
     def setUp(self):
         quodlibet.config.init()
-        self.fname = tempfile.mkstemp()[1]
+        h, self.fname = mkstemp()
+        os.close(h)
         f = file(self.fname, "w")
         f.write(self.memory)
         f.close()
@@ -88,13 +89,18 @@ class TComboBoxEntrySave(TestCase):
         os.unlink(self.fname + ".saved")
         quodlibet.config.quit()
 
+
 class TStandaloneEditor(TestCase):
-    TEST_KV_DATA = [("Search Foo", "https://foo.com/search?q=<artist>-<title>")]
+    TEST_KV_DATA = [
+        ("Search Foo", "https://foo.com/search?q=<artist>-<title>")]
+
     def setUp(self):
         quodlibet.config.init()
-        self.fname = tempfile.mkstemp()[1]
+        h, self.fname = mkstemp()
+        os.close(h)
         f = file(self.fname + ".saved", "w")
-        f.write("%s\n%s\n" % (self.TEST_KV_DATA[0][1], self.TEST_KV_DATA[0][0]))
+        f.write(
+            "%s\n%s\n" % (self.TEST_KV_DATA[0][1], self.TEST_KV_DATA[0][0]))
         f.close()
         self.sae = StandaloneEditor(self.fname, "test", None, None)
 
@@ -129,6 +135,3 @@ class TStandaloneEditor(TestCase):
         except OSError:
             pass
         quodlibet.config.quit()
-
-add(TComboBoxEntrySave)
-add(TStandaloneEditor)
