@@ -1,4 +1,4 @@
-from tests import TestCase, add
+from tests import TestCase
 
 from gi.repository import Gtk
 
@@ -7,6 +7,7 @@ from quodlibet.library import SongLibrary
 from quodlibet.qltk.completion import EntryWordCompletion, LibraryTagCompletion
 from quodlibet.qltk.completion import LibraryValueCompletion
 
+
 class TEntryWordCompletion(TestCase):
     def test_ctr(self):
         w = EntryWordCompletion()
@@ -15,7 +16,7 @@ class TEntryWordCompletion(TestCase):
         self.failUnlessEqual(w.get_entry(), e)
         self.failUnlessEqual(e.get_completion(), w)
         e.destroy()
-add(TEntryWordCompletion)
+
 
 class TLibraryTagCompletion(TestCase):
     def test_ctr(self):
@@ -25,7 +26,7 @@ class TLibraryTagCompletion(TestCase):
         self.failUnlessEqual(w.get_entry(), e)
         self.failUnlessEqual(e.get_completion(), w)
         e.destroy()
-add(TLibraryTagCompletion)
+
 
 class TLibraryValueCompletion(TestCase):
     def setUp(self):
@@ -41,4 +42,3 @@ class TLibraryValueCompletion(TestCase):
         self.failUnlessEqual(w.get_entry(), e)
         self.failUnlessEqual(e.get_completion(), w)
         e.destroy()
-add(TLibraryValueCompletion)
