@@ -4,14 +4,15 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 
-from tests import TestCase, add
+from tests import TestCase
 
 from quodlibet.qltk.controls import PlayControls, ReplayGainMenu, SeekBar
-from quodlibet.qltk.controls import StopAfterMenu, Volume
+from quodlibet.qltk.controls import Volume
 from quodlibet.library import SongLibrary
 from quodlibet.player.nullbe import NullPlayer
 from quodlibet import config
 
+
 class TControls(TestCase):
     def setUp(self):
         config.init()
@@ -33,12 +34,6 @@ class TControls(TestCase):
         w = SeekBar(self.p, self.l)
         w.destroy()
 
-    def test_stopafter(self):
-        w = StopAfterMenu(self.p)
-        w.destroy()
-
     def test_volume(self):
         w = Volume(self.p)
         w.destroy()
-
-add(TControls)
