@@ -7,19 +7,16 @@
 import sys
 
 from tests import TestCase
+from helper import capture_output
 
 from quodlibet.qltk.debugwindow import ExceptionDialog
 
 
 class TExceptionDialog(TestCase):
     def test_exec_hook(self):
-        old = sys.stderr
-        try:
-            sys.stderr = None
+        with capture_output():
             try:
                 raise Exception
             except Exception:
                 ExceptionDialog.from_except(*sys.exc_info())
                 ExceptionDialog.instance.destroy()
-        finally:
-            sys.stderr = old
