@@ -1,8 +1,9 @@
-from tests import TestCase, add
+from tests import TestCase
 
 from quodlibet.qltk.downloader import DownloadWindow
 import quodlibet.config
 
+
 class TDownloadWindow(TestCase):
     def setUp(self):
         quodlibet.config.init()
@@ -14,4 +15,3 @@ class TDownloadWindow(TestCase):
     def tearDown(self):
         self.win.destroy()
         quodlibet.config.quit()
-add(TDownloadWindow)
