@@ -4,15 +4,17 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
 
-from tests import TestCase, add
+from tests import TestCase
 
 from quodlibet.qltk.edittags import *
 from quodlibet.library import SongLibrary
 import quodlibet.config
 
+
 class TEditTags(TestCase):
     def setUp(self):
         quodlibet.config.init()
+
     def tearDown(self):
         quodlibet.config.quit()
 
@@ -25,5 +27,3 @@ class TEditTags(TestCase):
     def test_addtag_dialog(self):
         lib = SongLibrary()
         AddTagDialog(None, ["artist"], lib).destroy()
-
-add(TEditTags)
