@@ -1,9 +1,10 @@
-from tests import TestCase, add
+from tests import TestCase
 
 from quodlibet.qltk.exfalsowindow import ExFalsoWindow
 from quodlibet.library import SongLibrary
 import quodlibet.config
 
+
 class TExFalsoWindow(TestCase):
     def setUp(self):
         quodlibet.config.init()
@@ -15,4 +16,3 @@ class TExFalsoWindow(TestCase):
     def tearDown(self):
         self.ef.destroy()
         quodlibet.config.quit()
-add(TExFalsoWindow)
