@@ -1,15 +1,17 @@
-from tests import TestCase, add
+from tests import TestCase
 
 from quodlibet.formats._audio import AudioFile
 from quodlibet.library import SongLibrary
 from quodlibet.qltk.information import Information
 import quodlibet.config
 
+
 def AF(*args, **kwargs):
     a = AudioFile(*args, **kwargs)
     a.sanitize()
     return a
 
+
 class TInformation(TestCase):
     def setUp(self):
         quodlibet.config.init()
@@ -40,4 +42,3 @@ class TInformation(TestCase):
     def tearDown(self):
         self.library.destroy()
         quodlibet.config.quit()
-add(TInformation)
