@@ -1,6 +1,7 @@
 from tests import TestCase
 
 from quodlibet.qltk.prefs import PreferencesWindow
+from quodlibet.qltk.songlist import set_columns
 from quodlibet import config
 
 
@@ -9,7 +10,7 @@ class TPreferencesWindow(TestCase):
     def setUp(self):
         config.init()
         # Avoid warnings when running with empty config
-        config.set_columns(["artist", "title"])
+        set_columns(["artist", "title"])
         self.win = PreferencesWindow(None)
 
     def test_ctr(self):
