@@ -3,7 +3,7 @@ from tests import TestCase
 from gi.repository import Gtk
 
 from quodlibet.player.nullbe import NullPlayer
-from quodlibet.qltk.queue import QueueExpander
+from quodlibet.qltk.queue import QueueExpander, PlaybackStatusIcon
 from quodlibet.library import SongLibrary
 import quodlibet.config
 
@@ -17,6 +17,13 @@ class TQueueExpander(TestCase):
     def test_ctr(self):
         pass
 
+    def test_status_icon(self):
+        widget = PlaybackStatusIcon()
+        widget.play()
+        widget.stop()
+        widget.pause()
+        widget.pause()
+
     def tearDown(self):
         self.queue.destroy()
         quodlibet.config.quit()
