@@ -1,72 +1,96 @@
-from tests import TestCase, add
+from tests import TestCase
+
+import os
 
 from quodlibet.qltk.tagsfrompath import TagsFromPattern
-from quodlibet.qltk.tagsfrompath import TitleCase, SplitTag, UnderscoresToSpaces
+from quodlibet.qltk.tagsfrompath import (TitleCase, SplitTag,
+    UnderscoresToSpaces)
 import quodlibet.config
 
+
 class FilterTestCase(TestCase):
     def setUp(self):
         quodlibet.config.init()
         self.c = self.Kind()
+
     def tearDown(self):
         self.c.destroy()
         quodlibet.config.quit()
 
+
 class TTitleCase(FilterTestCase):
     Kind = TitleCase
+
     def test_simple(self):
         self.failUnlessEqual(self.c.filter("title", "foo bar"), "Foo Bar")
+
     def test_apostrophe(self):
         self.failUnlessEqual(self.c.filter("title", "IT's"), "IT's")
 
-add(TTitleCase)
 
 class TSplitTag(FilterTestCase):
     Kind = SplitTag
+
     def test_simple(self):
         self.failUnlessEqual(self.c.filter("title", "foo & bar"), "foo\nbar")
-add(TSplitTag)
+
 
 class TUnderscoresToSpaces(FilterTestCase):
     Kind = UnderscoresToSpaces
+
     def test_simple(self):
         self.failUnlessEqual(self.c.filter("titke", "foo_bar"), "foo bar")
-add(TUnderscoresToSpaces)
+
 
 class TTagsFromPattern(TestCase):
+
     def setUp(self):
-        self.f1 = '/path/Artist/Album/01 - Title.mp3'
-        self.f2 = '/path/Artist - Album/01. Title.mp3'
-        self.f3 = '/path/01 - Artist - Title.mp3'
-        self.b1 = '/path/01 - Title'
-        self.b2 = '/path/01 - Artist - Title'
+        if os.name == "nt":
+            self.f1 = 'C:\\path\\Artist\\Album\\01 - Title.mp3'
+            self.f2 = 'C:\\path\\Artist - Album\\01. Title.mp3'
+            self.f3 = 'C:\\path\\01 - Artist - Title.mp3'
+            self.b1 = 'C:\\path\\01 - Title'
+            self.b2 = 'C:\\path\\01 - Artist - Title'
+
+        else:
+            self.f1 = '/path/Artist/Album/01 - Title.mp3'
+            self.f2 = '/path/Artist - Album/01. Title.mp3'
+            self.f3 = '/path/01 - Artist - Title.mp3'
+            self.b1 = '/path/01 - Title'
+            self.b2 = '/path/01 - Artist - Title'
         self.nomatch = {}
 
     def test_songtypes(self):
         from quodlibet import formats
         pat = TagsFromPattern('<tracknumber>. <title>')
-        tracktitle = {'tracknumber': '01', 'title': 'Title' }
+        tracktitle = {'tracknumber': '01', 'title': 'Title'}
         for ext, kind in formats._infos.iteritems():
             f = formats._audio.AudioFile()
             if not isinstance(kind, type):
                 continue
             f.__class__ = kind
-            f["~filename"] = '/path/Artist - Album/01. Title' + ext
+            if os.name == "nt":
+                f["~filename"] = 'C:\\path\\Artist - Album\\01. Title' + ext
+            else:
+                f["~filename"] = '/path/Artist - Album/01. Title' + ext
             self.assertEquals(pat.match(f), tracktitle, ext)
 
     def test_skip(self):
-        pat = TagsFromPattern('<path>/<~>/<~>/<tracknumber> - <title>')
+        if os.name == "nt":
+            pat = TagsFromPattern('<path>\\<~>\\<~>\\<tracknumber> - <title>')
+        else:
+            pat = TagsFromPattern('<path>/<~>/<~>/<tracknumber> - <title>')
         self.failUnlessEqual(len(pat.headers), 3)
-        song = pat.match({"~filename":self.f1})
+        song = pat.match({"~filename": self.f1})
         self.failUnlessEqual(song.get("path"), "path")
         self.failUnlessEqual(song.get("title"), "Title")
         self.failIf(song.get("album"))
         self.failIf(song.get("artist"))
 
     def test_dict(self):
-        tracktitle = {'tracknumber': '01', 'title': 'Title' }
+        tracktitle = {'tracknumber': '01', 'title': 'Title'}
         pat = TagsFromPattern('<tracknumber> - <title>')
-        self.assertEquals(pat.match({"~filename":self.f1}), tracktitle)
+        self.assertEquals(pat.match({"~filename": self.f1}), tracktitle)
 
     def test_nongreedy(self):
         pat = TagsFromPattern('<artist> - <title>')
@@ -83,8 +107,8 @@ class TTagsFromPattern(TestCase):
         self.assertEquals(pat.match(self.b2), self.nomatch)
 
     def test_tracktitle(self):
-        tracktitle = {'tracknumber': '01', 'title': 'Title' }
-        btracktitle = {'tracknumber': '01', 'title': 'Artist - Title' }
+        tracktitle = {'tracknumber': '01', 'title': 'Title'}
+        btracktitle = {'tracknumber': '01', 'title': 'Artist - Title'}
         pat = TagsFromPattern('<tracknumber> - <title>')
         self.assertEquals(pat.match(self.f1), tracktitle)
         self.assertEquals(pat.match(self.f2), self.nomatch)
@@ -94,10 +118,13 @@ class TTagsFromPattern(TestCase):
 
     def test_path(self):
         albumtracktitle = {'tracknumber': '01', 'title': 'Title',
-                           'album': 'Album' }
+                           'album': 'Album'}
         balbumtracktitle = {'tracknumber': '01', 'title': 'Artist - Title',
-                            'album': 'path' }
-        pat = TagsFromPattern('<album>/<tracknumber> - <title>')
+                            'album': 'path'}
+        if os.name == "nt":
+            pat = TagsFromPattern('<album>\\<tracknumber> - <title>')
+        else:
+            pat = TagsFromPattern('<album>/<tracknumber> - <title>')
         self.assertEquals(pat.match(self.f1), albumtracktitle)
         self.assertEquals(pat.match(self.f2), self.nomatch)
         self.assertEquals(pat.match(self.f3), balbumtracktitle)
@@ -106,8 +133,11 @@ class TTagsFromPattern(TestCase):
 
     def test_all(self):
         all = {'tracknumber': '01', 'title': 'Title',
-               'album': 'Album', 'artist': 'Artist' }
-        pat = TagsFromPattern('<artist>/<album>/<tracknumber> - <title>')
+               'album': 'Album', 'artist': 'Artist'}
+        if os.name == "nt":
+            pat = TagsFromPattern('<artist>\\<album>\\<tracknumber> - <title>')
+        else:
+            pat = TagsFromPattern('<artist>/<album>/<tracknumber> - <title>')
         self.assertEquals(pat.match(self.f1), all)
         self.assertEquals(pat.match(self.f2), self.nomatch)
         self.assertEquals(pat.match(self.f3), self.nomatch)
@@ -115,8 +145,8 @@ class TTagsFromPattern(TestCase):
         self.assertEquals(pat.match(self.b2), self.nomatch)
 
     def test_post(self):
-        btracktitle = {'tracknumber': '01', 'title': 'Titl' }
-        vbtracktitle = {'tracknumber': '01', 'title': 'Artist - Titl' }
+        btracktitle = {'tracknumber': '01', 'title': 'Titl'}
+        vbtracktitle = {'tracknumber': '01', 'title': 'Artist - Titl'}
         pat = TagsFromPattern('<tracknumber> - <title>e')
         self.assertEquals(pat.match(self.f1), btracktitle)
         self.assertEquals(pat.match(self.f2), self.nomatch)
@@ -140,4 +170,3 @@ class TTagsFromPattern(TestCase):
             dict(discnumber='13', tracknumber='18', title='T18'))
         self.assertEquals(pat.match('24. T4.ogg'),
             dict(discnumber='2', tracknumber='4', title='T4'))
-add(TTagsFromPattern)
