@@ -1,7 +1,8 @@
-from tests import TestCase, add
+from tests import TestCase
 
 from quodlibet.qltk.textedit import TextEditBox, TextEdit
 
+
 class TTextEditBox(TestCase):
     def setUp(self):
         self.box = TextEditBox()
@@ -18,12 +19,11 @@ class TTextEditBox(TestCase):
 
     def tearDown(self):
         self.box.destroy()
-add(TTextEditBox)
+
 
 class TTextEdit(TTextEditBox):
     def setUp(self):
         self.box = TextEdit(None)
-add(TTextEdit)
 
 
 class TTextEditBox2(TestCase):
@@ -36,9 +36,8 @@ class TTextEditBox2(TestCase):
 
     def tearDown(self):
         self.foobar.destroy()
-add(TTextEditBox2)
+
 
 class TTextEdit2(TTextEditBox2):
     def setUp(self):
         self.foobar = TextEdit(None, "foobar")
-add(TTextEdit2)
