@@ -1,22 +1,30 @@
-from tests import TestCase, add
+from tests import TestCase
 
 from gi.repository import Gtk
 
 from quodlibet.qltk.wlw import WaitLoadWindow
 
+
 class TWaitLoadWindow(TestCase):
+
     class DummyConnector(Gtk.Window):
         count = 0
-        def connect(self, *args): self.count += 1
-        def disconnect(self, *args): self.count -= 1
+
+        def connect(self, *args):
+            self.count += 1
+
+        def disconnect(self, *args):
+            self.count -= 1
+
         class Eater:
-            def set_cursor(*args): pass
+            def set_cursor(*args):
+                pass
+
         window = Eater()
-    
+
     def setUp(self):
         self.parent = self.DummyConnector()
         self.wlw = WaitLoadWindow(self.parent, 5, "a test")
-        self.wlw.hide()
 
     def test_none(self):
         wlw = WaitLoadWindow(None, 5, "a test")
@@ -24,7 +32,9 @@ class TWaitLoadWindow(TestCase):
         wlw.destroy()
 
     def test_connect(self):
-        self.failUnlessEqual(1, self.parent.count)
+        self.failUnlessEqual(2, self.parent.count)
+        self.wlw.destroy()
+        self.failUnlessEqual(0, self.parent.count)
 
     def test_start(self):
         self.failUnlessEqual(0, self.wlw.current)
@@ -43,4 +53,3 @@ class TWaitLoadWindow(TestCase):
 
     def tearDown(self):
         self.wlw.destroy()
-add(TWaitLoadWindow)
