@@ -11,7 +11,7 @@ except ImportError:
     import md5 as hash
 
 from quodlibet.util import thumbnails
-from quodlibet.util.path import expanduser, pathname2url, is_fsnative
+from quodlibet.util.path import expanduser, pathname2url, is_fsnative, getcwd
 
 
 class TThumb(TestCase):
@@ -22,11 +22,17 @@ class TThumb(TestCase):
             GdkPixbuf.Colorspace.RGB, True, 8, 10, 100)
         s.small = GdkPixbuf.Pixbuf.new(
             GdkPixbuf.Colorspace.RGB, True, 8, 10, 20)
-        s.filename = os.path.join(os.getcwd(), "test_thumbnail.png")
+        s.filename = os.path.join(getcwd(), "test_thumbnail.png")
         s.wide.savev(s.filename, "png", [], [])
 
-    def tearDown(s):
-        os.remove(s.filename)
+    def tearDown(self):
+        p1 = thumbnails.get_cache_info(self.filename, (10, 10))[0]
+        p2 = thumbnails.get_cache_info(self.filename, (1000, 1000))[0]
+        for path in [p1, p2, self.filename]:
+            try:
+                os.remove(path)
+            except OSError:
+                pass
 
     def test_calc_scale_size(self):
         self.assertRaises(ValueError,
@@ -35,9 +41,18 @@ class TThumb(TestCase):
         self.assertEqual(res, (100, 20))
 
     def test_add_border(self):
-        res = thumbnails.add_border(self.small, 10)
-        self.assertEqual(res.get_width(), 10 + 2)
-        self.assertEqual(res.get_height(), 20 + 2)
+        w, h = self.small.get_width(), self.small.get_height()
+        res = thumbnails.add_border(self.small, 42, round=False)
+        self.assertEqual(res.get_width(), w + 2)
+        self.assertEqual(res.get_height(), h + 2)
+
+        res = thumbnails.add_border(self.small, 42, round=True)
+        self.assertEqual(res.get_width(), w + 2)
+        self.assertEqual(res.get_height(), h + 2)
+
+        res = thumbnails.add_border(self.small, 42, width=2)
+        self.assertEqual(res.get_width(), w + 4)
+        self.assertEqual(res.get_height(), h + 4)
 
     def test_get_thumbnail_folder(self):
         path = thumbnails.get_thumbnail_folder()
@@ -83,6 +98,23 @@ class TThumb(TestCase):
         self.assertTrue(thumb is None)
         fn.close()
 
+    def test_get_cache_info(self):
+        p, s = thumbnails.get_cache_info(self.filename, (20, 20))
+        self.assertEqual(s, 128)
+        self.assertTrue((os.sep + "normal" + os.sep) in p)
+
+        p, s = thumbnails.get_cache_info(self.filename, (20, 300))
+        self.assertEqual(s, 256)
+        self.assertTrue((os.sep + "large" + os.sep) in p)
+
+    def test_recreate_broken_cache_file(self):
+        thumb = thumbnails.get_thumbnail(self.filename, (50, 60))
+        self.assertTrue(thumb)
+        path, size = thumbnails.get_cache_info(self.filename, (50, 60))
+        open(path, "wb").close()
+        thumb = thumbnails.get_thumbnail(self.filename, (50, 60))
+        self.assertTrue(thumb)
+
     def test_thumb(s):
         thumb = thumbnails.get_thumbnail(s.filename, (50, 60))
 
